
# multi-machine emulation makefile
# whitespace is significant; use tab and four spaces for indent
# for cross-platform win32 compatibility.

# Examples:
# make maketree
#            -> build destination object tree for USER CONFIGURATION
# make win32
#            -> compile for win32/using msvs c compiler
#               (dos-mode compile w/ msvs not working yet)
# make win32clean
#            -> clean compile for win32/using msvs c compiler
# make cleantiny
#            -> tiny compile clean
#               if you switch on or off any of MESS, NEOGEO, or MAME,
#               you must do at least this.  if there is a problem
#               you might have to do a full clean...
# make clean
#            -> total clean make
# make mess32dist
#            -> make a compiled-executable distribution package
# make mess32srcdist
#            -> make a source distribution package relative to /cverge.cur/src
# wip:
# make cleanmedium
#            -> mess clean
# 



# USER CONFIGURATION AREA
# Overall Compilation control configuration:

# variables for defining compilation workings

# use EMULATOR_BASE to define compiled executable basenames
EMULATOR_BASE = mess32

# EMULATOR_BASE = mame
# EMULATOR_BASE = mess
# EMULATOR_BASE = neomame
# EMULATOR_BASE = neomess
# EMULATOR_BASE = neo32
# EMULATOR_BASE = mme
# EMULATOR_BASE = mme32

# turn on or off mess, neogeo, or mame compilation...

# if you turn things on or off here, you should
# make at least make cleantiny and maybe make clean
# to rebuild from a clean state

# uncomment to compile mess support
MESS = 1

# uncomment to compile neogeo support
# NEOGEO = 1

# uncomment to compile mame support
# MAME = 1

# uncomment WIN32 to build for WIN32
WIN32 = 1

# uncomment next line to include the symbols for symify
# SYMBOLS = 1

# uncomment next line to use Assembler 68k engine
X86_ASM_68K = 1

# uncomment next line to use Assembler z80 engine
# X86_ASM_Z80 = 1

# uncomment next line to use Assembler 6800 engine
# X86_ASM_6800 = 1

# uncomment next line to include the debugger
# DEBUG = 1

# uncomment next line to do a smaller compile including only one driver
# TINY_COMPILE = 1



# END OF GENERAL USER CONFIGURABLE PARAMETERS



!ifdef TINY_COMPILE

!ifdef MESS

TINY_NAME = a800xl_driver
TINY_OBJS = \
                obj/mess/machine/atari.o    \
                obj/mess/vidhrdw/antic.o    \
                obj/mess/vidhrdw/gtia.o     \
                obj/mess/vidhrdw/atari.o    \
                obj/mess/systems/atari.o    \
                obj/mess/vidhrdw/a7800.o    \
                obj/mess/machine/a7800.o    \
                obj/mess/systems/a7800.o    \
                obj/mess/machine/riot.o    \
                obj/mess/vidhrdw/a2600.o    \
                obj/mess/machine/a2600.o    \
                obj/mess/systems/a2600.o

!else

TINY_NAME = finalizr_driver
TINY_OBJS = obj/drivers/finalizr.o obj/vidhrdw/finalizr.o obj/machine/konami.o

!endif
!endif



# environment configuration dependent defines


!ifdef WIN32_

DESTARCH = -DWIN32

VERSION = -DVERSION=36

BETA_VERSION = -DBETA_VERSION=14

# MAME_DEBUG= -DMAME_DEBUG

MAME_MMX= -DMAME_MMX

MAME_NET= -DMAME_NET

USE_FASTCALL = 1

# uncomment to build without SEAL
# NOSEAL =

# uncomment to build without MIDAS
# NOMIDAS =

# uncomment to build Helpfiles
# HELPFILE = Mame32.hlp

AR= link.exe -FORCE:UNRESOLVED
# AR= link.exe -INCREMENTAL:YES  -FORCE:UNRESOLVED
CC      = cl.exe
LD      = link.exe
RSC     = rc.exe
ASM     = nasmw.exe
RM= del

ASMFLAGS = -f win32
ASMDEFS =
CDEFS = $(CPUDEFS) $(SOUNDDEFS) $(ASMDEFS) $(DEBUGDEF)

EMULATOR_EXE = $(EMULATOR_BASE).exe

!else

DESTARCH = -DDOS

AR = ar
CC = gcc
LD = gcc

#ASM = nasm
ASM = nasmw
ASMFLAGS = -f coff
VPATH=src $(wildcard src/cpu/*)

# uncomment below line to turn on UPX
EXECOMPRESS = upx



!ifdef K6
EMULATOR_EXE = $(EMULATOR_BASE)k6.exe
ARCH = -march=k6
!else
!ifdef I686
EMULATOR_EXE = $(EMULATOR_BASE)ppro.exe
ARCH = -march=pentiumpro
!else
EMULATOR_EXE = $(EMULATOR_BASE).exe
ARCH = -march=pentium
!endif
!endif


DEFS = -DX86_ASM -DLSB_FIRST -DINLINE="static __inline__" -Dasm=__asm__
CDEFS = $(DEFS) $(CPUDEFS) $(SOUNDDEFS) $(ASMDEFS) $(DEBUGDEF)

!ifdef SYMBOLS

# Sorry for the -Wno-unused, but I was tired ;)
CFLAGS = -Isrc -Isrc/msdos -Iobj/cpu/m68000 -Isrc/cpu/m68000 \
-Isrc/cpu/m6502 -O0 -pedantic -Wall -Werror -Wno-unused -g

!else

CFLAGS = -Isrc -Isrc/msdos -Iobj/cpu/m68000 -Isrc/cpu/m68000 \
-Isrc/cpu/m6502 $(ARCH) -O3 -fomit-frame-pointer -fstrict-aliasing \
-Werror -Wall -Wno-sign-compare -Wunused \
-Wpointer-arith -Wbad-function-cast -Wcast-align -Waggregate-return \
-pedantic \
-Wshadow \
-Wstrict-prototypes
#   -W had to remove because of the "missing initializer" warning
#-Wredundant-decls \
#-Wlarger-than-27648 \
#-Wcast-qual \
#-Wwrite-strings \
#-Wconversion \
#-Wmissing-prototypes \
#-Wmissing-declarations

!endif

!ifdef SYMBOLS
LDFLAGS =
!else
!ifndef WIN32_
LDFLAGS = -s
!else
LDFLAGS = -s -Wl,--warn-common
!endif
!endif

LIBS   = -lalleg -laudio -lz \


!endif


# utilize some mame infrastructure



!ifndef NEOGEO
CDEFS = $(CDEFS)  -DNEOFREE
!endif


!ifdef X86_ASM_Z80
Z80OBJS = obj/cpu/z80/z80.oa
80DEF = -nasm -verbose 0
!else
Z80OBJS = obj/cpu/z80/z80.o
z80DEF =
!endif

!ifdef X86_ASM_6800
M6800OBJS = obj/cpu/m6800/m6800.oa
!else
M6800OBJS = obj/cpu/m6800/m6800.o
!endif




!ifdef WIN32_

# if ("$(PROCESSOR_ARCHITECTURE)" == "")
PROCESSOR_ARCHITECTURE=x86
# !endif

!ifdef MAME_NET
NET_LIBS = wsock32.lib
!else
NET_LIBS =
!endif



#DEFS   = -DLSB_FIRST -DWIN32 -DPI=3.1415926535 -DINLINE="static __inline" -Dinline=__inline -D__inline__=__inline \
DEFS   = -DLSB_FIRST -DWIN32 -DPI=3.1415926535 -DM_PI=3.1415926535 -DINLINE="static __inline" -Dinline=__inline -D__inline__=__inline \
-DPNG_SAVE_SUPPORT -D_WINDOWS -DZLIB_DLL $(CDEFS)

AUDIOFLAGS =
AUDIOOBJS  =
AUDIOLIBS  =

!ifndef NOSEAL
AUDIOFLAGS = -ISEAL
AUDIOOBJS  = obj/Win32/SealSound.o
AUDIOLIBS  = SEAL/Audw32vc.lib 
!else
AUDIOFLAGS = -DNOSEAL
!endif

!ifndef NOMIDAS
AUDIOFLAGS = $(AUDIOFLAGS) -IMIDAS
AUDIOOBJS  = $(AUDIOOBJS) obj/Win32/MIDASSound.o
AUDIOLIBS  = $(AUDIOLIBS) MIDAS/MIDAS.lib
!else
AUDIOFLAGS = $(AUDIOFLAGS) -DNOMIDAS
#AUDIOFLAGS += -DNOMIDAS
!endif

CFLAGSGLOBAL = -Gr -I.  -Isrc -Iobj/cpu/m68000 -Isrc/cpu/m68000 -Isrc/Win32 \
              -IZLIB $(AUDIOFLAGS) -W3 -nologo -MT \
              $(MAME_DEBUG) $(RELEASE_CANDIDATE) $(BETA_VERSION) $(VERSION) \
              $(MAME_NET) $(MAME_MMX) $(HAS_CPUS) $(HAS_SOUND)

CFLAGSDEBUG = -Zi -Od

CFLAGSOPTIMIZED = -DNDEBUG -Ox -G5 -Ob2

!ifdef DEBUG
CFLAGS = $(CFLAGSGLOBAL) $(CFLAGSDEBUG)
!else
CFLAGS = $(CFLAGSGLOBAL) $(CFLAGSOPTIMIZED)
!endif

!ifdef USE_FASTCALL
CFLAGS = $(CFLAGS) -DCLIB_DECL=__cdecl -DDECL_SPEC=__cdecl -DFASTCALL
!endif

LDFLAGSGLOBAL = -subsystem:windows -machine:$(PROCESSOR_ARCHITECTURE) -nologo /NODEFAULTLIB:libc.lib

LDFLAGSDEBUG = -debug:full
LDFLAGSOPTIMIZED = -release -incremental:no -map

!ifdef DEBUG
LDFLAGS = $(LDFLAGSGLOBAL) $(LDFLAGSDEBUG)
!else
LDFLAGS = $(LDFLAGSGLOBAL) $(LDFLAGSOPTIMIZED)
!endif

RCFLAGS = -l 0x409 -DNDEBUG -IWin32 $(MAME_NET) $(MAME_MMX)

LIBS   = kernel32.lib user32.lib gdi32.lib comctl32.lib comdlg32.lib advapi32.lib \
        winmm.lib shell32.lib dinput.lib dxguid.lib vfw32.lib ZLIB\zlib.lib \
        $(AUDIOLIBS)


!ifdef MAME_NET
NET_OBJS = obj/Win32/netchat32.o obj/network.o obj/Win32/net32.o 
!else
NET_OBJS =
!endif

WIN32_OBJS = \
        obj/Win32/osdepend.o \
        obj/Win32/MAME32.o obj/Win32/M32Util.o \
        obj/Win32/directinput.o obj/Win32/DIKeyboard.o obj/Win32/DIJoystick.o \
        obj/Win32/uclock.o \
        obj/Win32/Display.o obj/Win32/GDIDisplay.o obj/Win32/DDrawWindow.o obj/Win32/DDrawDisplay.o \
        obj/Win32/DirectDraw.o obj/Win32/RenderBitmap.o obj/Win32/Dirty.o \
        obj/Win32/led.o obj/Win32/status.o \
        $(AUDIOOBJS) obj/Win32/DirectSound.o obj/Win32/NullSound.o \
        obj/Win32/Keyboard.o obj/Win32/Joystick.o obj/Win32/Trak.o \
        obj/Win32/file.o obj/Win32/Directories.o obj/Win32/mzip.o \
        obj/Win32/debug.o \
        obj/Win32/fmsynth.o obj/Win32/NTFMSynth.o \
        obj/Win32/audit32.o \
        obj/Win32/Win32ui.o obj/Win32/Properties.o obj/Win32/ColumnEdit.o \
        obj/Win32/Screenshot.o obj/Win32/TreeView.o obj/Win32/Splitters.o \
        obj/Win32/options.o obj/Win32/Bitmask.o obj/Win32/DataMap.o \
        obj/Win32/Avi.o \
        obj/Win32/RenderMMX.o


CFLAGS = $(CFLAGS) $(TINYFLAGS)
# nmake doesn't handle += correctly...
#CFLAGS += $(TINYFLAGS)

RES    = obj/Win32/MAME32.res


!ifdef HELPFILE
all: $(EMULATOR_EXE) $(HELPFILE)

!else
all: $(EMULATOR_EXE)

!endif

# workaround for vc4.2 compiler optimization bug:

!ifndef DEBUG
obj/vidhrdw/timeplt.o: src/vidhrdw/timeplt.c
       $(CC) $(DEFS) $(CFLAGSGLOBAL) -Oi -Ot -Oy -Ob1 -Gs -G5 -Gr -Fo$@ -c src/vidhrdw/timeplt.c

!endif


# obj/Win32/Win32.a: $(WIN32_OBJS)
#        $(AR) $(WIN32_OBJS) -out:obj/Win32/Win32.a

# mame32.exe: $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES)
#$(LD) $(LDFLAGS) -out:mame32.exe $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES) $(LIBS) $(NET_LIBS)
# mame32.exe: $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES)
# $(LD) $(LDFLAGS) -out:mame32.exe $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES) $(LIBS) $(NET_LIBS)

# mame32.exe: $(COREOBJS) obj/Win32/Win32.a $(OBJS) $(RES)
#        $(LD) $(LDFLAGS) -out:mame32.exe $(COREOBJS) obj/Win32/Win32.a $(OBJS) $(RES) $(LIBS) $(NET_LIBS)

# mame32.exe: $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES)
#        $(LD) $(LDFLAGS) -out:mame32.exe $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES) $(LIBS) $(NET_LIBS)

#$(LD) @<< \
#       $(LDFLAGS) -out:mame32.exe $(COREOBJS) $(WIN32_OBJS) $(OBJS) $(RES) $(LIBS) $(NET_LIBS) << \

!ifdef HELPFILE
$(HELPFILE): src\Win32\Hlp\Mame32.cnt src\Win32\Hlp\Mame32.hlp
       @Makehelp.bat
!endif

!ifdef WIN32_

.asm.oa:
        $(ASM) -o $@ $(ASMFLAGS) $(ASMDEFS) $<

{obj}.o: {src}.c
        $(CC) $(DEFS) $(CFLAGS) -c $< -Fo$@
#        $(CC) $(DEFS) $(CFLAGS) -c $< -Fo$@

{src}.c{obj}.o:
        $(CC) $(DEFS) $(CFLAGS) -c $< -Fo$@

#        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/Win32}.c{obj/Win32}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/ccpu}.c{obj/cpu/ccpu}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/gensync}.c{obj/cpu/gensync}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/h6280}.c{obj/cpu/h6280}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/i8039}.c{obj/cpu/i8039}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/i8085}.c{obj/cpu/i8085}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/i86}.c{obj/cpu/i86}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/konami}.c{obj/cpu/konami}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/m6502}.c{obj/cpu/m6502}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/m6800}.c{obj/cpu/m6800}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/m68000}.c{obj/cpu/m68000}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/m6805}.c{obj/cpu/m6805}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/m6809}.c{obj/cpu/m6809}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/nec}.c{obj/cpu/nec}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/adsp2100}.c{obj/cpu/adsp2100}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/pdp1}.c{obj/cpu/pdp1}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/s2650}.c{obj/cpu/s2650}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/t11}.c{obj/cpu/t11}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/tms32010}.c{obj/cpu/tms32010}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/tms34010}.c{obj/cpu/tms34010}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/tms9900}.c{obj/cpu/tms9900}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/z80}.c{obj/cpu/z80}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/z80gb}.c{obj/cpu/z80gb}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/cpu/z8000}.c{obj/cpu/z8000}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/vidhrdw}.c{obj/vidhrdw}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/sound}.c{obj/sound}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/machine}.c{obj/machine}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/systems}.c{obj/systems}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/drivers}.c{obj/drivers}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/sndhrdw}.c{obj/sndhrdw}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/mess}.c{obj/mess}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/mess/machine}.c{obj/mess/machine}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/msdos}.c{obj/msdos}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/mess/systems}.c{obj/mess/systems}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/mess/sndhrdw}.c{obj/mess/sndhrdw}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

{src/mess/vidhrdw}.c{obj/mess/vidhrdw}.o:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

# obj/Win32/MAME32.res:
# $(RSC) $(RCFLAGS) src/Win32/mame32.rc -Foobj/Win32/MAME32.res

#$(CC) $(RCFLAGS) src/Win32/mame32.rc -Foobj/Win32/MAME32.res


{src/Win32}.rc{obj/Win32}.res:
        $(RSC) $(RCFLAGS) -Fo$@ $<

obj/cpu/m6800/m6800.asm:  src/cpu/m6800/make6808.c
        $(CC) /Feobj/cpu/6800/make6808.exe /Foobj/cpu/m6800/make6808.obj src/cpu/m6800/make6808.c
        obj\\cpu\\m6800\\make6808 $@ -m -h -w

CFLAGS_MAKE_68K = -DWIN32
!ifdef USE_FASTCALL
CFLAGS_MAKE_68K = $(CFLAGS_MAKE_68K) -DFASTCALL
!endif

# generate C source files for the 68000 emulator
obj/cpu/m68000/m68kops.h \
obj/cpu/m68000/m68kops.c \
obj/cpu/m68000/m68kopac.c \
obj/cpu/m68000/m68kopdm.c \
obj/cpu/m68000/m68kopnz.c : src/cpu/m68000/m68kmake.c src/cpu/m68000/m68k_in.c
        $(CC) $(CFLAGS_MAKE_68K) /Feobj/cpu/m68000/m68kmake.exe /Foobj/cpu/m68000/m68kmake.obj \
        src/cpu/m68000/m68kmake.c
        obj\\cpu\\m68000\\m68kmake obj/cpu/m68000 src/cpu/m68000/m68k_in.c

# generated C files for the 68000 emulator
{obj/cpu/m68000}.c{obj/cpu/m68000}.og:
        $(CC) $(DEFS) $(CFLAGS) -Fo$@ -c $<

# generate asm source files for the 68000 emulator
# obj/cpu/m68000/68kem.asm:  src/cpu/m68000/make68k.c
# $(CC) $(CFLAGS_MAKE_68K) /Feobj/cpu/m68000/make68k.exe /Foobj/cpu/m68000/make68k.obj \
# src/cpu/m68000/make68k.c
# obj\\cpu\\m68000\\make68k $@

# obj/cpu/z80/z80.asm:  src/cpu/z80/makez80.c
# $(CC) $(CDEFS) $(CFLAGS) -Foobj/cpu/z80/makez80.exe src/cpu/z80/makez80.c
# obj\\cpu\\z80\\makez80 $(Z80DEF) $(CDEFS) $(CFLAGS) $@

# dependencies
obj/cpu/z80/z80.o:           src/cpu/z80/z80.c src/cpu/z80/z80.h src/cpu/z80/z80daa.h
obj/cpu/z8000/z8000.o: src/cpu/z8000/z8000.c src/cpu/z8000/z8000.h src/cpu/z8000/z8000cpu.h src/cpu/z8000/z8000dab.h src/cpu/z8000/z8000ops.c src/cpu/z8000/z8000tbl.c
obj/cpu/s2650/s2650.o: src/cpu/s2650/s2650.c src/cpu/s2650/s2650.h src/cpu/s2650/s2650cpu.h
obj/cpu/h6280/h6280.o: src/cpu/h6280/h6280.c src/cpu/h6280/h6280.h src/cpu/h6280/h6280ops.h src/cpu/h6280/tblh6280.c
obj/cpu/i8039/i8039.o: src/cpu/i8039/i8039.c src/cpu/i8039/i8039.h

obj/cpu/i86/i86.o: src/cpu/i86/i86.c src/cpu/i86/i86.h src/cpu/i86/i86intrf.h src/cpu/i86/ea.h src/cpu/i86/host.h src/cpu/i86/instr.h src/cpu/i86/modrm.h
obj/cpu/nec/nec.o: src/cpu/nec/nec.c src/cpu/nec/nec.h src/cpu/nec/necintrf.h src/cpu/nec/necea.h src/cpu/nec/nechost.h src/cpu/nec/necinstr.h src/cpu/nec/necmodrm.h
obj/cpu/m6800/m6800.o: src/cpu/m6800/m6800.c src/cpu/m6800/m6800.h src/cpu/m6800/6800ops.c src/cpu/m6800/6800tbl.c
obj/cpu/m6805/m6805.o:     src/cpu/m6805/m6805.c src/cpu/m6805/m6805.h src/cpu/m6805/6805ops.c
obj/cpu/m6809/m6809.o:     src/cpu/m6809/m6809.c src/cpu/m6809/m6809.h src/cpu/m6809/6809ops.c src/cpu/m6809/6809tbl.c
obj/cpu/tms32010/tms32010.o: src/cpu/tms32010/tms32010.c src/cpu/tms32010/tms32010.h
obj/cpu/t11/t11.o: src/cpu/t11/t11.c src/cpu/t11/t11.h src/cpu/t11/t11ops.c src/cpu/t11/t11table.c
obj/cpu/ccpu/ccpu.o:         src/cpu/ccpu/ccpu.h src/cpu/ccpu/ccpu.c src/cpu/ccpu/ccputabl.c

obj/cpu/m68000/m68kcpu.o: src/cpu/m68000/m68kops.c src/cpu/m68000/m68kmake.c src/cpu/m68000/m68k_in.c
obj/cpu/konami/konami.o: src/cpu/konami/konami.c src/cpu/konami/konami.h src/cpu/konami/konamops.c src/cpu/konami/konamtbl.c
obj/cpu/gensync/gensync.o: src/cpu/gensync/gensync.c src/cpu/gensync/gensync.h

# obj/cpu/i8039/i8039.o: src/cpu/i8039/8039dasm.c src/cpu/i8039/i8039.c src/cpu/i8039/i8039.h
obj/cpu/i8085/i8085.o:       src/cpu/i8085/i8085.c src/cpu/i8085/i8085.h src/cpu/i8085/i8085cpu.h src/cpu/i8085/i8085daa.h
obj/cpu/m6502/m6502.o:       src/cpu/m6502/m6502.c src/cpu/m6502/m6502.h src/cpu/m6502/m6502ops.h src/cpu/m6502/tbl6502.c src/cpu/m6502/tbl65c02.c src/cpu/m6502/tbl6510.c
# obj/cpu/h6280/h6280.o:       src/cpu/h6280/h6280.c src/cpu/h6280/h6280.h src/cpu/h6280/h6280ops.h src/cpu/h6280/tblh6280.c
# obj/cpu/i86/i86.o:           src/cpu/i86/i86.c src/cpu/i86/i86.h src/cpu/i86/i86intrf.h src/cpu/i86/ea.h src/cpu/i86/host.h src/cpu/i86/instr.h src/cpu/i86/modrm.h
# obj/cpu/m6800/m6800.o:     src/cpu/m6800/m6800.c src/cpu/m6800/m6800.h src/cpu/m6800/6800ops.c
# obj/cpu/tms34010/tms34010.o: src/cpu/tms34010/tms34010.c src/cpu/tms34010/tms34010.h src/cpu/tms34010/34010ops.c src/cpu/tms34010/34010tbl.c
obj/cpu/tms9900/tms9900.o:   src/cpu/tms9900/tms9900.c src/cpu/tms9900/tms9900.h src/cpu/tms9900/9900stat.h
# obj/cpu/m68000/m68kcpu.o:    obj/cpu/m68000/m68kops.c src/cpu/m68000/m68kmake.c src/cpu/m68000/m68k_in.c

!endif

!endif







!ifdef MAME
# uncomment the following lines to include a CPU core
CPUS = $(CPUS) GENSYNC@
CPUS = $(CPUS) Z80@
#CPUS+=Z80_VM@
CPUS = $(CPUS) 8080@
CPUS = $(CPUS) 8085A@
CPUS = $(CPUS) M6502@
CPUS = $(CPUS) M65C02@
CPUS = $(CPUS) M6510@
CPUS = $(CPUS) N2A03@
CPUS = $(CPUS) H6280@
CPUS = $(CPUS) I86@
CPUS = $(CPUS) V20@
CPUS = $(CPUS) V30@
CPUS = $(CPUS) V33@
CPUS = $(CPUS) I8035@
CPUS = $(CPUS) I8039@
CPUS = $(CPUS) I8048@
CPUS = $(CPUS) N7751@
CPUS = $(CPUS) M6800@
CPUS = $(CPUS) M6801@
CPUS = $(CPUS) M6802@
CPUS = $(CPUS) M6803@
CPUS = $(CPUS) M6808@
CPUS = $(CPUS) HD63701@
CPUS = $(CPUS) NSC8105@
CPUS = $(CPUS) M6805@
CPUS = $(CPUS) M68705@
CPUS = $(CPUS) HD63705@
CPUS = $(CPUS) HD6309@
CPUS = $(CPUS) M6809@
CPUS = $(CPUS) KONAMI@
CPUS = $(CPUS) M68000@
CPUS = $(CPUS) M68010@
CPUS = $(CPUS) M68020@
CPUS = $(CPUS) T11@
CPUS = $(CPUS) S2650@
CPUS = $(CPUS) TMS34010@
CPUS = $(CPUS) TMS9900@
#CPUS+=TMS9940@
CPUS = $(CPUS) TMS9980@
#CPUS+=TMS9985@
#CPUS+=TMS9989@
#CPUS+=TMS9995@
#CPUS+=TMS99105@
#CPUS+=TMS99110@
CPUS = $(CPUS) Z8000@
CPUS = $(CPUS) TMS320C10@
CPUS = $(CPUS) CCPU@
CPUS = $(CPUS) ADSP2100@
#CPUS+=PDP1@

# MAME case; uncomment the following lines to include a sound core
SOUNDS = $(SOUNDS) CUSTOM@
SOUNDS = $(SOUNDS) SAMPLES@
SOUNDS = $(SOUNDS) DAC@
SOUNDS = $(SOUNDS) AY8910@
SOUNDS = $(SOUNDS) YM2203@
SOUNDS = $(SOUNDS) YM2151@
SOUNDS = $(SOUNDS) YM2151_ALT@
SOUNDS = $(SOUNDS) YM2608@
SOUNDS = $(SOUNDS) YM2610@
SOUNDS = $(SOUNDS) YM2610B@
SOUNDS = $(SOUNDS) YM2612@
SOUNDS = $(SOUNDS) YM3438@
SOUNDS = $(SOUNDS) YM2413@
SOUNDS = $(SOUNDS) YM3812@
SOUNDS = $(SOUNDS) Y8950@
SOUNDS = $(SOUNDS) YM3526@
SOUNDS = $(SOUNDS) SN76496@
SOUNDS = $(SOUNDS) POKEY@
#SOUNDS+=TIA@
SOUNDS = $(SOUNDS) NES@
SOUNDS = $(SOUNDS) ASTROCADE@
SOUNDS = $(SOUNDS) NAMCO@
SOUNDS = $(SOUNDS) TMS5220@
SOUNDS = $(SOUNDS) VLM5030@
SOUNDS = $(SOUNDS) ADPCM@
SOUNDS = $(SOUNDS) OKIM6295@
SOUNDS = $(SOUNDS) MSM5205@
SOUNDS = $(SOUNDS) UPD7759@
SOUNDS = $(SOUNDS) HC55516@
SOUNDS = $(SOUNDS) K007232@
SOUNDS = $(SOUNDS) K053260@
SOUNDS = $(SOUNDS) K005289@
SOUNDS = $(SOUNDS) SEGAPCM@
SOUNDS = $(SOUNDS) RF5C68@
SOUNDS = $(SOUNDS) CEM3394@
SOUNDS = $(SOUNDS) C140@
SOUNDS = $(SOUNDS) QSOUND@
SOUNDS = $(SOUNDS) K053260
SOUNDS = $(SOUNDS) K051649@

!endif

# NEOGEO-specific components

!ifdef NEOGEO

CPUS = $(CPUS) Z80@
CPUS = $(CPUS) M68000@
SOUNDS = $(SOUNDS) YM2610@

!endif

# MESS components

!ifdef MESS

#CPUS+=GENSYNC@
CPUS = $(CPUS) Z80@
CPUS = $(CPUS) Z80GB@
#CPUS+=Z80_VM@
#CPUS+=8080@
#CPUS+=8085A@
CPUS = $(CPUS) M6502@
CPUS = $(CPUS) M65C02@
CPUS = $(CPUS) M6510@
CPUS = $(CPUS) N2A03@
CPUS = $(CPUS) H6280@
CPUS = $(CPUS) I86@
#CPUS+=V20@
#CPUS+=V30@
#CPUS+=V33@
#CPUS+=I8035@
#CPUS+=I8039@
#CPUS+=I8048@
#CPUS+=N7751@
#CPUS+=M6800@
#CPUS+=M6801@
#CPUS+=M6802@
#CPUS+=M6803@
#CPUS+=M6808@
#CPUS+=HD63701@
#CPUS+=M6805@
#CPUS+=M68705@
#CPUS+=HD63705@
#CPUS+=HD6309@
CPUS = $(CPUS) M6809@
#CPUS+=KONAMI@
CPUS = $(CPUS) M68000@
#CPUS+=M68010@
#CPUS+=M68020@
#CPUS+=T11@
#CPUS+=S2650@
#CPUS+=TMS34010@
CPUS = $(CPUS) TMS9900@
#CPUS+=Z8000@
#CPUS+=TMS320C10@
#CPUS+=CCPU@
CPUS = $(CPUS) PDP1@

# MESS case; uncomment the following lines to include a sound core
SOUNDS = $(SOUNDS) CUSTOM@
SOUNDS = $(SOUNDS) SAMPLES@
SOUNDS = $(SOUNDS) DAC@
SOUNDS = $(SOUNDS) AY8910@
#SOUNDS+=YM2203@
#SOUNDS+=YM2151@
#SOUNDS+=YM2151_ALT@
#SOUNDS+=YM2608@
SOUNDS = $(SOUNDS) YM2610@
#SOUNDS+=YM2610B@
SOUNDS = $(SOUNDS) YM2612@
#SOUNDS+=YM3438@
#SOUNDS+=YM2413@
SOUNDS = $(SOUNDS) YM3812@
#SOUNDS+=YM3526@
SOUNDS = $(SOUNDS) SN76496@
SOUNDS = $(SOUNDS) POKEY@
SOUNDS = $(SOUNDS) TIA@
SOUNDS = $(SOUNDS) NES@
SOUNDS = $(SOUNDS) ASTROCADE@
#SOUNDS+=NAMCO@
SOUNDS = $(SOUNDS) TMS5220@
#SOUNDS+=VLM5030@
#SOUNDS+=ADPCM@
#SOUNDS+=OKIM6295@
#SOUNDS+=MSM5205@
#SOUNDS+=UPD7759@
#SOUNDS+=HC55516@
#SOUNDS+=K007232@
#SOUNDS+=K053260@
#SOUNDS+=SEGAPCM@
#SOUNDS+=RF5C68@
#SOUNDS+=CEM3394@
#SOUNDS+=C140@

!endif    # MESS



# do not include the next section in the win32-generated makefile
























# END STRIP WIN32



# List of CPU core (and, for a debug build, disassembler) object files
CPUDEFS =
CPUOBJS =
DBGOBJS =
ASMDEFS =

!undef CPU
CPU=(strip (findstring GENSYNC@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_GENSYNC=1
CPUOBJS = $(CPUOBJS)  obj/cpu/gensync/gensync.o
DBGOBJS = $(DBGOBJS)  obj/cpu/gensync/gensyncd.o
!endif

!undef CPU
CPU=(strip (findstring Z80@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_Z80=1
CPUOBJS = $(CPUOBJS)  obj/cpu/z80/z80.o
DBGOBJS = $(DBGOBJS)  obj/cpu/z80/z80dasm.o
!endif

!undef CPU
CPU=(strip (findstring Z80GB@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_Z80GB=1
CPUOBJS = $(CPUOBJS)  obj/cpu/z80gb/z80gb.o
DBGOBJS = $(DBGOBJS)  obj/cpu/z80gb/z80gbd.o
!endif

# CPU=$(strip $(findstring Z80_VM@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_Z80_VM=1
# CPUOBJS += obj/cpu/z80/z80_vm.o
# DBGOBJS += obj/cpu/z80/z80dasm.o
# !endif

!undef CPU
CPU=(strip (findstring 8080@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_8080=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8085/i8085.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8085/8085dasm.o
!endif

!undef CPU
CPU=(strip (findstring 8085A@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_8085A=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8085/i8085.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8085/8085dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6502@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6502=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6502/m6502.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6502/6502dasm.o
!endif

!undef CPU
CPU=(strip (findstring M65C02@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M65C02=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6502/m6502.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6502/6502dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6510@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6510=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6502/m6502.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6502/6502dasm.o
!endif

!undef CPU
CPU=(strip (findstring N2A03@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_N2A03=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6502/m6502.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6502/6502dasm.o
!endif

!undef CPU
CPU=(strip (findstring H6280@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_H6280=1
CPUOBJS = $(CPUOBJS)  obj/cpu/h6280/h6280.o
DBGOBJS = $(DBGOBJS)  obj/cpu/h6280/6280dasm.o
!endif

!undef CPU
CPU=(strip (findstring I86@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_I86=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i86/i86.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i86/i86dasm.o
!endif

!undef CPU
CPU=(strip (findstring V20@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_V20=1
CPUOBJS = $(CPUOBJS)  obj/cpu/nec/nec.o
DBGOBJS = $(DBGOBJS)  obj/cpu/nec/necdasm.o
!endif

!undef CPU
CPU=(strip (findstring V30@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_V30=1
CPUOBJS = $(CPUOBJS)  obj/cpu/nec/nec.o
DBGOBJS = $(DBGOBJS)  obj/cpu/nec/necdasm.o
!endif

!undef CPU
CPU=(strip (findstring V33@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_V33=1
CPUOBJS = $(CPUOBJS)  obj/cpu/nec/nec.o
DBGOBJS = $(DBGOBJS)  obj/cpu/nec/necdasm.o
!endif

!undef CPU
CPU=(strip (findstring I8035@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_I8035=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8039/i8039.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8039/8039dasm.o
!endif

!undef CPU
CPU=(strip (findstring I8039@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_I8039=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8039/i8039.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8039/8039dasm.o
!endif

!undef CPU
CPU=(strip (findstring I8048@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_I8048=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8039/i8039.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8039/8039dasm.o
!endif

!undef CPU
CPU=(strip (findstring N7751@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_N7751=1
CPUOBJS = $(CPUOBJS)  obj/cpu/i8039/i8039.o
DBGOBJS = $(DBGOBJS)  obj/cpu/i8039/8039dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6800@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6800=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6801@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6801=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6802@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6802=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6803@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6803=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6808@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6808=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring HD63701@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_HD63701=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring NSC8105@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_NSC8105=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6800/m6800.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6800/6800dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6805@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6805=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6805/m6805.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6805/6805dasm.o
!endif

!undef CPU
CPU=(strip (findstring M68705@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M68705=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6805/m6805.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6805/6805dasm.o
!endif

!undef CPU
CPU=(strip (findstring HD63705@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_HD63705=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6805/m6805.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6805/6805dasm.o
!endif

!undef CPU
CPU=(strip (findstring HD6309@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_HD6309=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6809/m6809.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6809/6809dasm.o
!endif

!undef CPU
CPU=(strip (findstring M6809@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M6809=1
CPUOBJS = $(CPUOBJS)  obj/cpu/m6809/m6809.o
DBGOBJS = $(DBGOBJS)  obj/cpu/m6809/6809dasm.o
!endif

!undef CPU
CPU=(strip (findstring KONAMI@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_KONAMI=1
CPUOBJS = $(CPUOBJS)  obj/cpu/konami/konami.o
DBGOBJS = $(DBGOBJS)  obj/cpu/konami/knmidasm.o
!endif

!undef CPU
CPU=(strip (findstring M68000@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M68000=1
!ifdef X86_ASM_68K
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/asmintf.o obj/cpu/m68000/68kem.oa
ASMDEFS = $(ASMDEFS)  -DA68KEM
!else
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/m68kops.og obj/cpu/m68000/m68kopac.og \
           obj/cpu/m68000/m68kopdm.og obj/cpu/m68000/m68kopnz.og \
           obj/cpu/m68000/m68kcpu.o obj/cpu/m68000/m68kmame.o
!endif
DBGOBJS = $(DBGOBJS)  obj/cpu/m68000/d68k.o
!endif

!undef CPU
CPU=(strip (findstring M68010@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M68010=1
!ifdef X86_ASM_68K
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/asmintf.o obj/cpu/m68000/68kem.oa
ASMDEFS = $(ASMDEFS)  -DA68KEM
!else
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/m68kops.og obj/cpu/m68000/m68kopac.og \
           obj/cpu/m68000/m68kopdm.og obj/cpu/m68000/m68kopnz.og \
           obj/cpu/m68000/m68kcpu.o obj/cpu/m68000/m68kmame.o
!endif
DBGOBJS = $(DBGOBJS)  obj/cpu/m68000/d68k.o
!endif

!undef CPU
CPU=(strip (findstring M68020@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_M68020=1
!ifdef X86_ASM_68K
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/asmintf.o obj/cpu/m68000/68kem.oa
ASMDEFS = $(ASMDEFS)  -DA68KEM
!else
CPUOBJS = $(CPUOBJS)  obj/cpu/m68000/m68kops.og obj/cpu/m68000/m68kopac.og \
           obj/cpu/m68000/m68kopdm.og obj/cpu/m68000/m68kopnz.og \
           obj/cpu/m68000/m68kcpu.o obj/cpu/m68000/m68kmame.o
!endif
DBGOBJS = $(DBGOBJS)  obj/cpu/m68000/d68k.o
!endif

!undef CPU
CPU=(strip (findstring T11@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_T11=1
CPUOBJS = $(CPUOBJS)  obj/cpu/t11/t11.o
DBGOBJS = $(DBGOBJS)  obj/cpu/t11/t11dasm.o
!endif

!undef CPU
CPU=(strip (findstring S2650@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_S2650=1
CPUOBJS = $(CPUOBJS)  obj/cpu/s2650/s2650.o
DBGOBJS = $(DBGOBJS)  obj/cpu/s2650/2650dasm.o
!endif

!undef CPU
CPU=(strip (findstring TMS34010@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_TMS34010=1
CPUOBJS = $(CPUOBJS)  obj/cpu/tms34010/tms34010.o obj/cpu/tms34010/34010fld.o
DBGOBJS = $(DBGOBJS)  obj/cpu/tms34010/34010dsm.o
!endif

!undef CPU
CPU=(strip (findstring TMS9900@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_TMS9900=1
CPUOBJS = $(CPUOBJS)  obj/cpu/tms9900/tms9900.o
DBGOBJS = $(DBGOBJS)  obj/cpu/tms9900/9900dasm.o
!endif

# CPU=$(strip $(findstring TMS9940@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS9940=1
# CPUOBJS += obj/cpu/tms9900/tms9900.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

!undef CPU
CPU=(strip (findstring TMS9980@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_TMS9980=1
CPUOBJS = $(CPUOBJS)  obj/cpu/tms9900/tms9980a.o
DBGOBJS = $(DBGOBJS)  obj/cpu/tms9900/9900dasm.o
!endif

# CPU=$(strip $(findstring TMS9985@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS9985=1
# CPUOBJS += obj/cpu/tms9900/tms9980a.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

# CPU=$(strip $(findstring TMS9989@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS9989=1
# CPUOBJS += obj/cpu/tms9900/tms9980a.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

# CPU=$(strip $(findstring TMS9995@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS9995=1
# CPUOBJS += obj/cpu/tms9900/tms9995.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

# CPU=$(strip $(findstring TMS99105A@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS99105A=1
# CPUOBJS += obj/cpu/tms9900/tms9995.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

# CPU=$(strip $(findstring TMS99110A@,$(CPUS)))
# ifneq ($(CPU),)
# CPUDEFS += -DHAS_TMS99110A=1
# CPUOBJS += obj/cpu/tms9900/tms9995.o
# DBGOBJS += obj/cpu/tms9900/9900dasm.o
# !endif

!undef CPU
CPU=(strip (findstring Z8000@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_Z8000=1
CPUOBJS = $(CPUOBJS)  obj/cpu/z8000/z8000.o
DBGOBJS = $(DBGOBJS)  obj/cpu/z8000/8000dasm.o
!endif

!undef CPU
CPU=(strip (findstring TMS320C10@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_TMS320C10=1
CPUOBJS = $(CPUOBJS)  obj/cpu/tms32010/tms32010.o
DBGOBJS = $(DBGOBJS)  obj/cpu/tms32010/32010dsm.o
!endif

!undef CPU
CPU=(strip (findstring CCPU@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_CCPU=1
CPUOBJS = $(CPUOBJS)  obj/cpu/ccpu/ccpu.o obj/vidhrdw/cinemat.o
DBGOBJS = $(DBGOBJS)  obj/cpu/ccpu/ccpudasm.o
!endif

!undef CPU
CPU=(strip (findstring ADSP2100@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_ADSP2100=1
CPUOBJS = $(CPUOBJS)  obj/cpu/adsp2100/adsp2100.o
DBGOBJS = $(DBGOBJS)  obj/cpu/adsp2100/2100dasm.o
!endif

!undef CPU
CPU=(strip (findstring PDP1@,$CPUS))
!ifdef CPU
CPUDEFS = $(CPUDEFS)  -DHAS_PDP1=1
CPUOBJS = $(CPUOBJS)  obj/cpu/pdp1/pdp1.o
DBGOBJS = $(DBGOBJS)  obj/cpu/pdp1/pdp1dasm.o
!endif



!undef SOUND
SOUND=(strip (findstring CUSTOM@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_CUSTOM=1
!endif

!undef SOUND
SOUND=(strip (findstring SAMPLES@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_SAMPLES=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/samples.o
!endif

!undef SOUND
SOUND=(strip (findstring DAC@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_DAC=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/dac.o
!endif

!undef SOUND
SOUND=(strip (findstring AY8910@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_AY8910=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/ay8910.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2203@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2203=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2203intf.o obj/sound/ay8910.o obj/sound/fm.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2151@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2151=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2151intf.o obj/sound/ym2151.o obj/sound/fm.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2151_ALT@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2151_ALT=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2151intf.o obj/sound/ym2151.o obj/sound/fm.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2608@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2608=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2608intf.o obj/sound/ay8910.o obj/sound/fm.o obj/sound/ymdeltat.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2610@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2610=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2610intf.o obj/sound/ay8910.o obj/sound/fm.o obj/sound/ymdeltat.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2610B@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2610B=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2610intf.o obj/sound/ay8910.o obj/sound/fm.o obj/sound/ymdeltat.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2612@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2612=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2612intf.o obj/sound/ay8910.o obj/sound/fm.o
!endif

!undef SOUND
SOUND=(strip (findstring YM3438@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM3438=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/2612intf.o obj/sound/ay8910.o obj/sound/fm.o
!endif

!undef SOUND
SOUND=(strip (findstring YM2413@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM2413=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/3812intf.o obj/sound/ym2413.o obj/sound/fmopl.o
# SOUNDOBJS += obj/sound/3812intf.o obj/sound/ym2413.o obj/sound/ym3812.o obj/sound/fmopl.o
!endif

!undef SOUND
SOUND=(strip (findstring YM3812@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM3812=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/3812intf.o obj/sound/fmopl.o
# SOUNDOBJS += obj/sound/3812intf.o obj/sound/ym3812.o obj/sound/fmopl.o
!endif

!undef SOUND
SOUND=(strip (findstring YM3526@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_YM3526=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/3812intf.o obj/sound/fmopl.o
# SOUNDOBJS += obj/sound/3812intf.o obj/sound/ym3812.o obj/sound/fmopl.o
!endif

!undef SOUND
SOUND=(strip (findstring Y8950@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_Y8950=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/3812intf.o obj/sound/fmopl.o obj/sound/ymdeltat.o
!endif

!undef SOUND
SOUND=(strip (findstring SN76496@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_SN76496=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/sn76496.o
!endif

!undef SOUND
SOUND=(strip (findstring POKEY@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_POKEY=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/pokey.o
!endif

!undef SOUND
SOUND=(strip (findstring TIA@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_TIA=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/tiasound.o obj/sound/tiaintf.o
!endif

!undef SOUND
SOUND=(strip (findstring NES@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_NES=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/nes_apu.o
# SOUNDOBJS += obj/sound/nes.o obj/sound/nesintf.o
!endif

!undef SOUND
SOUND=(strip (findstring ASTROCADE@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_ASTROCADE=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/astrocde.o
!endif

!undef SOUND
SOUND=(strip (findstring NAMCO@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_NAMCO=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/namco.o
!endif

!undef SOUND
SOUND=(strip (findstring TMS5220@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_TMS5220=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/tms5220.o obj/sound/5220intf.o
!endif

!undef SOUND
SOUND=(strip (findstring VLM5030@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_VLM5030=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/vlm5030.o
!endif

!undef SOUND
SOUND=(strip (findstring ADPCM@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_ADPCM=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/adpcm.o
!endif

!undef SOUND
SOUND=(strip (findstring OKIM6295@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_OKIM6295=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/adpcm.o
!endif

!undef SOUND
SOUND=(strip (findstring MSM5205@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_MSM5205=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/msm5205.o
!endif

!undef SOUND
SOUND=(strip (findstring K005289@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_K005289=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/k005289.o
!endif

!undef SOUND
SOUND=(strip (findstring K051649@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_K051649=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/k051649.o
!endif

!undef SOUND
SOUND=(strip (findstring QSOUND@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_QSOUND=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/qsound.o
!endif

!undef SOUND
SOUND=(strip (findstring UPD7759@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_UPD7759=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/upd7759.o
!endif

!undef SOUND
SOUND=(strip (findstring HC55516@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_HC55516=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/hc55516.o
!endif

!undef SOUND
SOUND=(strip (findstring K007232@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_K007232=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/k007232.o
!endif

!undef SOUND
SOUND=(strip (findstring K053260@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_K053260=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/k053260.o
!endif

!undef SOUND
SOUND=(strip (findstring SEGAPCM@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_SEGAPCM=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/segapcm.o
!endif

!undef SOUND
SOUND=(strip (findstring RF5C68@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_RF5C68=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/rf5c68.o
!endif

!undef SOUND
SOUND=(strip (findstring CEM3394@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_CEM3394=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/cem3394.o
!endif

!undef SOUND
SOUND=(strip (findstring C140@,(SOUNDS)))
!ifdef SOUND
SOUNDDEFS = $(SOUNDDEFS)  -DHAS_C140=1
SOUNDOBJS = $(SOUNDOBJS)  obj/sound/c140.o
!endif



!ifdef DEBUG
DEBUGDEF = -DMAME_DEBUG
!else
DEBUGDEF =
DBGOBJS =
!endif

!ifdef MESS
COREOBJS = obj/version.o obj/mess/system.o obj/mame.o obj/mess/mess.o
!ifdef WIN32_
COREOBJS = $(COREOBJS)  obj/mess/win32.o
!endif
!else
COREOBJS = obj/version.o obj/driver.o obj/mame.o
!endif

COREOBJS = $(COREOBJS)  \
         obj/drawgfx.o obj/common.o obj/usrintrf.o \
         obj/cpuintrf.o obj/memory.o obj/timer.o obj/palette.o \
         obj/input.o obj/inptport.o obj/cheat.o obj/unzip.o \
         obj/audit.o obj/info.o obj/png.o obj/artwork.o \
         obj/tilemap.o obj/sprite.o obj/gfxobj.o \
 obj/state.o obj/datafile.o \
          $(CPUOBJS) \
         obj/sndintrf.o \
 obj/sound/streams.o obj/sound/mixer.o \
          $(SOUNDOBJS) \
 obj/sound/votrax.o \
         obj/machine/z80fmly.o obj/machine/6821pia.o \
 obj/machine/8255ppi.o \
         obj/vidhrdw/generic.o obj/vidhrdw/vector.o \
         obj/vidhrdw/avgdvg.o obj/machine/mathbox.o \
         obj/machine/ticket.o \
         obj/mamedbg.o obj/window.o \
         obj/profiler.o \
          $(DBGOBJS) \

# LIBS for all

!ifdef MESS

MESSLIBS = \
          obj/coleco.a   \
          obj/sega.a     \
          obj/atarih.a   \
          obj/gce.a      \
          obj/nintendo.a \
          obj/cbm.a      \
          obj/dragon.a   \
          obj/kaypro.a   \
          obj/dragon.a   \
          obj/trs80.a    \
          obj/cgenie.a   \
          obj/pdp1.a     \
          obj/sinclair.a \
          obj/apple2.a   \
          obj/ti99.a     \
          obj/bally.a    \
          obj/pc.a       \
          obj/amstrad.a  \
          obj/nec.a      \
          obj/ep128.a    \
          obj/ascii.a    \
          obj/other.a    \


!endif

!ifdef MAME

MAMELIBS = obj/pacman.a obj/galaxian.a obj/scramble.a \
         obj/cclimber.a obj/nichibut.a \
         obj/phoenix.a obj/namco.a obj/univers.a obj/nintendo.a \
         obj/midw8080.a obj/midwz80.a obj/meadows.a obj/midway.a \
         obj/irem.a obj/gottlieb.a obj/taito.a obj/toaplan.a \
 obj/kyugo.a obj/williams.a obj/gremlin.a obj/vicdual.a \
         obj/capcom.a obj/capbowl.a obj/leland.a \
         obj/sega.a obj/dataeast.a obj/tehkan.a obj/konami.a \
         obj/exidy.a obj/atari.a obj/rockola.a obj/snk.a obj/technos.a \
         obj/berzerk.a obj/gameplan.a obj/stratvox.a obj/zaccaria.a \
         obj/upl.a obj/tms.a obj/cinemar.a obj/cinemav.a obj/thepit.a \
         obj/valadon.a obj/seibu.a obj/tad.a obj/jaleco.a obj/visco.a \
         obj/orca.a obj/gaelco.a obj/other.a \

!endif



NEOLIBS = obj/neogeo.a \

MSDOSOBJS = obj/msdos/msdos.o obj/msdos/video.o obj/msdos/blit.o obj/msdos/vector.o \
         obj/msdos/sound.o obj/msdos/input.o obj/msdos/fileio.o obj/msdos/config.o \
         obj/msdos/fronthlp.o \
         obj/msdos/gen15khz.o obj/msdos/ati15khz.o 

!ifdef MESS
MSDOSOBJS = $(MSDOSOBJS)  obj/msdos/nec765.o
!endif

!ifdef TINY_COMPILE
OBJS = $(TINY_OBJS)
TINYFLAGS = -DTINY_COMPILE -DTINY_NAME=$(TINY_NAME)
!else
!ifdef NEOGEO
OBJS = $(NEOLIBS)
TINYFLAGS = -DNEOGEO
!endif
!ifdef MAME
OBJS = $(OBJS)  $(MAMELIBS)
TINYFLAGS = $(TINYFLAGS)  -DMAME
!endif
!ifdef MESS
OBJS = $(OBJS)  $(MESSLIBS)
TINYFLAGS = $(TINYFLAGS)  -DMESS -DMME
!endif
!endif

!ifndef WIN32_

all: $(EMULATOR_EXE) romcmp.exe

!endif


# always recompile the version string
# !ifdef MESS
#$(CC) $(CDEFS) $(CFLAGS) $(TINYFLAGS) -DMESS -c src/version.c -o obj/version.o
#!else
#!endif

# what's the $^ interpretation - variable, but which one?  breaks nmake...
#        $(LD) $(LDFLAGS) $^ -lz -o $@


obj/%.o: src/%.c
!ifdef MESS
    $(CC) $(CDEFS) $(CFLAGS) $(TINYFLAGS) -DMESS -DMME -c $< -o $@
!else
    $(CC) $(CDEFS) $(CFLAGS) $(TINYFLAGS) -c $< -o $@
!endif

# generate C source files for the 68000 emulator
obj/cpu/m68000/%.c obj/cpu/m68000/%.h: src/cpu/m68000/m68kmake.c src/cpu/m68000/m68k_in.c
    $(CC) $(CDEFS) $(CFLAGS) -DDOS -o obj/cpu/m68000/m68kmake.exe $<
    obj/cpu/m68000/m68kmake obj/cpu/m68000 src/cpu/m68000/m68k_in.c

# generated C files for the 68000 emulator
obj/%.og: obj/%.c
    $(CC) $(CDEFS) $(CFLAGS) $(TINYFLAGS) -c $< -o $@

# generate asm source files for the 68000 emulator
obj/cpu/m68000/68kem.asm:  src/cpu/m68000/make68k.c
    $(CC) $(CDEFS) $(CFLAGS) $(DESTARCH) -O0 -o obj/cpu/m68000/make68k.exe src/cpu/m68000/make68k.c
!ifndef WIN32_
    obj/cpu/m68000/make68k.exe obj/cpu/m68000/68kem.asm
!else
    obj\cpu\m68000\make68k.exe obj/cpu/m68000/68kem.asm
!endif

#        $(CC) $(CDEFS) $(CFLAGS) $(DESTARCH) -o obj/cpu/m68000/make68k.exe $<
#$(CC) $(CDEFS) $(CFLAGS) -DDOS -o obj/cpu/m68000/make68k.exe $<

# generated asm files for the 68000 emulator
obj/cpu/m68000/68kem.oa:  obj/cpu/m68000/68kem.asm
!ifndef WIN32_
    $(ASM) -o $@ $(ASMFLAGS) (subst -D,-d,$(ASMDEFS)) $<
!else
    $(ASM) -o $@ $(ASMFLAGS) -dA68KEM obj/cpu/m68000/68kem.asm -o obj/cpu/m68000/68kem.oa
!endif

#        $(ASM) -o $@ $(ASMFLAGS) (subst -D,-d,$(ASMDEFS)) $<

obj/cpu/z80/z80.asm:  src/cpu/z80/makez80.c
    $(CC) $(CDEFS) $(CFLAGS) $(DESTARCH) -o obj/cpu/z80/makez80.exe $<
    obj/cpu/z80/makez80 $(Z80DEF) $(CDEFS) $(CFLAGS) $@

#$(CC) $(CDEFS) $(CFLAGS) -DDOS -o obj/cpu/z80/makez80.exe $<

!ifndef WIN32_
obj/%.a:
    $(AR) cr $@ $^
#       $(AR) cr $@
!endif


!ifdef MESS

obj/coleco.a:   \
    obj/mess/vidhrdw/tms9928a.o \
    obj/mess/machine/coleco.o   \
    obj/mess/vidhrdw/coleco.o   \
    obj/mess/systems/coleco.o   \

obj/sega.a:     \
                obj/mess/vidhrdw/smsvdp.o   \
                obj/mess/machine/sms.o      \
                obj/mess/systems/sms.o      \
                obj/mess/sndhrdw/genesis.o  \
                obj/mess/vidhrdw/genesis.o  \
                obj/mess/machine/genesis.o  \
                obj/mess/systems/genesis.o  \

obj/atarih.a:    \
                obj/mess/machine/atari.o    \
                obj/mess/vidhrdw/antic.o    \
                obj/mess/vidhrdw/gtia.o     \
                obj/mess/vidhrdw/atari.o    \
                obj/mess/systems/atari.o    \
                obj/mess/vidhrdw/a7800.o    \
                obj/mess/machine/a7800.o    \
                obj/mess/systems/a7800.o    \
                obj/mess/machine/riot.o    \
                obj/mess/vidhrdw/a2600.o    \
                obj/mess/machine/a2600.o    \
                obj/mess/systems/a2600.o    \

obj/gce.a:      \
                obj/mess/machine/6522via.o  \
                obj/mess/vidhrdw/vectrex.o  \
                obj/mess/machine/vectrex.o  \
                obj/mess/systems/vectrex.o  \

obj/nintendo.a: \
                obj/mess/machine/nes_mmc.o  \
                obj/mess/vidhrdw/nes.o      \
                obj/mess/machine/nes.o      \
                obj/mess/systems/nes.o      \
obj/mess/vidhrdw/gb.o  \
obj/mess/machine/gb.o  \
obj/mess/systems/gb.o

obj/cbm.a:      \
                obj/mess/vidhrdw/amiga.o    \
                obj/mess/machine/amiga.o    \
                obj/mess/systems/amiga.o    \
obj/mess/vidhrdw/vic6560.o  \
obj/mess/sndhrdw/vic6560.o  \
obj/mess/machine/6522via.o \
obj/mess/machine/vc20.o     \
obj/mess/machine/vc20tape.o     \
obj/mess/machine/vc1541.o     \
obj/mess/systems/vc20.o     \
obj/mess/vidhrdw/ted7360.o  \
obj/mess/sndhrdw/ted7360.o  \
obj/mess/machine/c1551.o    \
obj/mess/machine/c16.o      \
obj/mess/systems/c16.o    


obj/dragon.a:   \
                obj/mess/vidhrdw/dragon.o   \
                obj/mess/machine/dragon.o   \
                obj/mess/systems/dragon.o   \

obj/trs80.a:    \
                obj/mess/machine/trs80.o    \
                obj/mess/machine/wd179x.o   \
                obj/mess/vidhrdw/trs80.o    \
                obj/mess/systems/trs80.o    \

obj/cgenie.a:   \
                obj/mess/machine/cgenie.o   \
                obj/mess/machine/wd179x.o   \
                obj/mess/vidhrdw/cgenie.o    \
                obj/mess/sndhrdw/cgenie.o   \
                obj/mess/systems/cgenie.o   \
#obj/msdos/nec765.o

obj/pdp1.a:     \
                obj/mess/vidhrdw/pdp1.o     \
                obj/mess/machine/pdp1.o     \
                obj/mess/systems/pdp1.o     \

obj/kaypro.a:   \
                obj/mess/machine/cpm_bios.o \
                obj/mess/vidhrdw/kaypro.o   \
                obj/mess/machine/kaypro.o   \
                obj/mess/systems/kaypro.o   \
               #obj/mess/machine/cpm_disk.o \      this is screwed ;-)

obj/sinclair.a: \
                obj/mess/vidhrdw/spectrum.o \
                obj/mess/machine/spectrum.o \
                obj/mess/systems/spectrum.o \
                obj/mess/vidhrdw/zx.o \
                obj/mess/machine/zx.o \
                obj/mess/systems/zx.o \

obj/apple2.a:   \
                obj/mess/machine/ay3600.o   \
                obj/mess/machine/ap_disk2.o \
                obj/mess/vidhrdw/apple2.o   \
                obj/mess/machine/apple2.o   \
                obj/mess/systems/apple2.o   \

obj/ti99.a:     \
                obj/mess/machine/ti99_4x.o     \
                obj/mess/systems/ti99_4x.o     \
                #obj/mess/systems/ti99_2.o     \

obj/bally.a:    \
                obj/sound/astrocde.o        \
                obj/mess/vidhrdw/astrocde.o \
                obj/mess/machine/astrocde.o \
                obj/mess/systems/astrocde.o \

obj/pc.a:       \
                obj/mess/sndhrdw/pc.o       \
                obj/mess/vidhrdw/pc_cga.o   \
                obj/mess/vidhrdw/pc_mda.o   \
                obj/mess/vidhrdw/pc_t1t.o   \
                obj/mess/machine/pc.o       \
                obj/mess/machine/pc_fdc.o   \
                obj/mess/machine/pc_hdc.o   \
                obj/mess/machine/pc_ide.o   \
                obj/mess/systems/pc.o       \

#                obj/mess/vidhrdw/pc.o       \

obj/amstrad.a:  \
                obj/machine/8255ppi.o  \
                obj/mess/vidhrdw/hd6845s.o  \
                obj/mess/vidhrdw/amstrad.o  \
                obj/mess/machine/nec765.o  \
                obj/mess/machine/amstrad.o  \
                obj/mess/systems/amstrad.o  \

obj/nec.a:  \
obj/mess/vidhrdw/vdc.o      \
                obj/mess/machine/pce.o      \
                obj/mess/systems/pce.o      \


obj/ep128.a :   \
                obj/mess/sndhrdw/dave.o     \
                obj/mess/vidhrdw/epnick.o   \
                obj/mess/vidhrdw/enterp.o   \
                obj/mess/machine/enterp.o   \
                obj/mess/systems/enterp.o   \

obj/ascii.a : \
                obj/mess/sndhrdw/scc.o \
obj/mess/vidhrdw/msx.o \
obj/mess/machine/msx.o \
obj/mess/systems/msx.o \

obj/other.a :   \
                obj/mess/vidhrdw/kim1.o     \
                obj/mess/machine/kim1.o     \
                obj/mess/systems/kim1.o     \
                obj/mess/vidhrdw/oric.o     \
                obj/mess/machine/oric.o     \
                obj/mess/systems/oric.o     \
                obj/mess/vidhrdw/vz.o     \
                obj/mess/machine/vz.o     \
                obj/mess/systems/vz.o     \
                obj/mess/vidhrdw/jupiter.o     \
                obj/mess/machine/jupiter.o     \
                obj/mess/systems/jupiter.o     \


!endif    # endif of !ifdef MESS

!ifdef MAME

obj/pacman.a: \
         obj/machine/pacman.o obj/drivers/pacman.o \
         obj/machine/pacplus.o \
         obj/machine/theglob.o \
         obj/machine/jrpacman.o obj/drivers/jrpacman.o obj/vidhrdw/jrpacman.o \
         obj/vidhrdw/pengo.o obj/drivers/pengo.o \

obj/galaxian.a: \
         obj/vidhrdw/galaxian.o obj/drivers/galaxian.o \
         obj/sndhrdw/mooncrst.o obj/drivers/mooncrst.o \

obj/scramble.a: \
         obj/machine/scramble.o obj/sndhrdw/scramble.o obj/drivers/scramble.o \
         obj/vidhrdw/frogger.o obj/sndhrdw/frogger.o obj/drivers/frogger.o \
         obj/drivers/scobra.o \
         obj/vidhrdw/amidar.o obj/drivers/amidar.o \
         obj/vidhrdw/fastfred.o obj/drivers/fastfred.o \

obj/cclimber.a: \
         obj/vidhrdw/cclimber.o obj/sndhrdw/cclimber.o obj/drivers/cclimber.o \
         obj/drivers/yamato.o \

obj/nichibut.a: \
         obj/vidhrdw/seicross.o obj/sndhrdw/wiping.o obj/drivers/seicross.o \
         obj/vidhrdw/wiping.o obj/drivers/wiping.o \
         obj/vidhrdw/cop01.o obj/drivers/cop01.o \
         obj/vidhrdw/terracre.o obj/drivers/terracre.o \
         obj/vidhrdw/galivan.o obj/drivers/galivan.o \
         obj/vidhrdw/armedf.o obj/drivers/armedf.o \

obj/phoenix.a: \
         obj/vidhrdw/phoenix.o obj/sndhrdw/phoenix.o obj/drivers/phoenix.o \
         obj/sndhrdw/pleiads.o \
         obj/vidhrdw/naughtyb.o obj/drivers/naughtyb.o \

obj/namco.a: \
         obj/vidhrdw/rallyx.o obj/drivers/rallyx.o \
         obj/drivers/locomotn.o \
         obj/machine/bosco.o obj/sndhrdw/bosco.o obj/vidhrdw/bosco.o obj/drivers/bosco.o \
         obj/machine/galaga.o obj/vidhrdw/galaga.o obj/drivers/galaga.o \
         obj/machine/digdug.o obj/vidhrdw/digdug.o obj/drivers/digdug.o \
         obj/vidhrdw/xevious.o obj/machine/xevious.o obj/drivers/xevious.o \
         obj/machine/superpac.o obj/vidhrdw/superpac.o obj/drivers/superpac.o \
         obj/machine/phozon.o obj/vidhrdw/phozon.o obj/drivers/phozon.o \
         obj/machine/mappy.o obj/vidhrdw/mappy.o obj/drivers/mappy.o \
         obj/machine/grobda.o obj/vidhrdw/grobda.o obj/drivers/grobda.o \
         obj/machine/gaplus.o obj/vidhrdw/gaplus.o obj/drivers/gaplus.o \
 obj/machine/polepos.o obj/vidhrdw/polepos.o obj/sndhrdw/polepos.o obj/drivers/polepos.o \
         obj/vidhrdw/pacland.o obj/drivers/pacland.o \
 obj/vidhrdw/skykid.o obj/drivers/skykid.o \
         obj/vidhrdw/baraduke.o obj/drivers/baraduke.o \
         obj/vidhrdw/namcos86.o obj/drivers/namcos86.o \
         obj/machine/namcos1.o obj/vidhrdw/namcos1.o obj/drivers/namcos1.o \
         obj/machine/namcos2.o obj/vidhrdw/namcos2.o obj/drivers/namcos2.o \

obj/univers.a: \
         obj/vidhrdw/cosmic.o obj/drivers/cosmic.o \
         obj/vidhrdw/cheekyms.o obj/drivers/cheekyms.o \
         obj/vidhrdw/ladybug.o obj/drivers/ladybug.o \
         obj/vidhrdw/mrdo.o obj/drivers/mrdo.o \
         obj/machine/docastle.o obj/vidhrdw/docastle.o obj/drivers/docastle.o \


obj/nintendo.a: \
         obj/vidhrdw/dkong.o obj/sndhrdw/dkong.o obj/drivers/dkong.o \
         obj/vidhrdw/mario.o obj/sndhrdw/mario.o obj/drivers/mario.o \
         obj/vidhrdw/popeye.o obj/drivers/popeye.o \
         obj/vidhrdw/punchout.o obj/sndhrdw/punchout.o obj/drivers/punchout.o \

obj/midw8080.a: \
         obj/machine/8080bw.o obj/vidhrdw/8080bw.o obj/sndhrdw/8080bw.o obj/drivers/8080bw.o \
         obj/vidhrdw/m79amb.o obj/drivers/m79amb.o \

obj/midwz80.a: \
         obj/vidhrdw/z80bw.o obj/sndhrdw/z80bw.o obj/drivers/z80bw.o \

obj/meadows.a: \
         obj/drivers/lazercmd.o obj/vidhrdw/lazercmd.o \
         obj/drivers/meadows.o obj/sndhrdw/meadows.o obj/vidhrdw/meadows.o \

obj/midway.a: \
         obj/machine/wow.o obj/vidhrdw/wow.o obj/sndhrdw/wow.o obj/drivers/wow.o \
         obj/sndhrdw/gorf.o \
         obj/machine/mcr.o obj/sndhrdw/mcr.o \
         obj/vidhrdw/mcr1.o obj/vidhrdw/mcr2.o obj/vidhrdw/mcr3.o \
         obj/drivers/mcr1.o obj/drivers/mcr2.o obj/drivers/mcr3.o \
         obj/vidhrdw/mcr68.o obj/drivers/mcr68.o \
         obj/vidhrdw/balsente.o obj/drivers/balsente.o \

obj/irem.a: \
         obj/vidhrdw/skychut.o obj/drivers/skychut.o \
         obj/sndhrdw/irem.o \
         obj/vidhrdw/mpatrol.o obj/drivers/mpatrol.o \
         obj/vidhrdw/troangel.o obj/drivers/troangel.o \
         obj/vidhrdw/yard.o obj/drivers/yard.o \
         obj/vidhrdw/travrusa.o obj/drivers/travrusa.o \
         obj/vidhrdw/m62.o obj/drivers/m62.o \
         obj/vidhrdw/vigilant.o obj/drivers/vigilant.o \
         obj/vidhrdw/m72.o obj/sndhrdw/m72.o obj/drivers/m72.o \
         obj/vidhrdw/shisen.o obj/drivers/shisen.o \
         obj/vidhrdw/m92.o obj/drivers/m92.o \
         obj/drivers/m97.o \
         obj/vidhrdw/m107.o obj/drivers/m107.o \

obj/gottlieb.a: \
         obj/vidhrdw/gottlieb.o obj/sndhrdw/gottlieb.o obj/drivers/gottlieb.o \

obj/taito.a: \
         obj/vidhrdw/crbaloon.o obj/drivers/crbaloon.o \
         obj/machine/qix.o obj/vidhrdw/qix.o obj/drivers/qix.o \
         obj/machine/taitosj.o obj/vidhrdw/taitosj.o obj/drivers/taitosj.o \
         obj/vidhrdw/bking2.o obj/drivers/bking2.o \
         obj/vidhrdw/gsword.o obj/drivers/gsword.o obj/machine/tait8741.o \
         obj/vidhrdw/retofinv.o obj/drivers/retofinv.o \
         obj/vidhrdw/tsamurai.o obj/drivers/tsamurai.o \
         obj/machine/flstory.o obj/vidhrdw/flstory.o obj/drivers/flstory.o \
         obj/vidhrdw/gladiatr.o obj/drivers/gladiatr.o \
         obj/machine/bublbobl.o obj/vidhrdw/bublbobl.o obj/drivers/bublbobl.o \
         obj/machine/mexico86.o obj/vidhrdw/mexico86.o obj/drivers/mexico86.o \
         obj/vidhrdw/rastan.o obj/sndhrdw/rastan.o obj/drivers/rastan.o \
         obj/machine/rainbow.o obj/drivers/rainbow.o \
         obj/machine/arkanoid.o obj/vidhrdw/arkanoid.o obj/drivers/arkanoid.o \
         obj/vidhrdw/superqix.o obj/drivers/superqix.o \
 obj/vidhrdw/minivadr.o obj/drivers/minivadr.o \
         obj/machine/tnzs.o obj/vidhrdw/tnzs.o obj/drivers/tnzs.o \
         obj/vidhrdw/superman.o obj/drivers/superman.o obj/machine/cchip.o \
 obj/vidhrdw/footchmp.o obj/drivers/footchmp.o \
         obj/drivers/lkage.o obj/vidhrdw/lkage.o \
         obj/vidhrdw/taitol.o obj/drivers/taitol.o \
         obj/vidhrdw/taitof2.o obj/drivers/taitof2.o \
         obj/vidhrdw/ssi.o obj/drivers/ssi.o \

obj/toaplan.a: \
         obj/machine/slapfght.o obj/vidhrdw/slapfght.o obj/drivers/slapfght.o \
         obj/machine/twincobr.o obj/vidhrdw/twincobr.o \
         obj/drivers/twincobr.o obj/drivers/wardner.o \
         obj/machine/toaplan1.o obj/vidhrdw/toaplan1.o obj/drivers/toaplan1.o \
         obj/vidhrdw/snowbros.o obj/drivers/snowbros.o \

obj/kyugo.a: \
         obj/drivers/kyugo.o obj/vidhrdw/kyugo.o \

obj/williams.a: \
         obj/machine/williams.o obj/vidhrdw/williams.o obj/sndhrdw/williams.o obj/drivers/williams.o \

obj/capcom.a: \
         obj/vidhrdw/vulgus.o obj/drivers/vulgus.o \
         obj/vidhrdw/sonson.o obj/drivers/sonson.o \
         obj/vidhrdw/higemaru.o obj/drivers/higemaru.o \
         obj/vidhrdw/1942.o obj/drivers/1942.o \
         obj/vidhrdw/exedexes.o obj/drivers/exedexes.o \
         obj/vidhrdw/commando.o obj/drivers/commando.o \
         obj/vidhrdw/gng.o obj/drivers/gng.o \
         obj/vidhrdw/gunsmoke.o obj/drivers/gunsmoke.o \
         obj/vidhrdw/srumbler.o obj/drivers/srumbler.o \
         obj/machine/lwings.o obj/vidhrdw/lwings.o obj/drivers/lwings.o \
         obj/vidhrdw/sidearms.o obj/drivers/sidearms.o \
         obj/vidhrdw/bionicc.o obj/drivers/bionicc.o \
         obj/vidhrdw/1943.o obj/drivers/1943.o \
         obj/vidhrdw/blktiger.o obj/drivers/blktiger.o \
         obj/vidhrdw/tigeroad.o obj/drivers/tigeroad.o \
         obj/vidhrdw/lastduel.o obj/drivers/lastduel.o \
         obj/vidhrdw/sf1.o obj/drivers/sf1.o \
         obj/machine/kabuki.o obj/machine/eeprom.o \
         obj/vidhrdw/mitchell.o obj/drivers/mitchell.o \
         obj/vidhrdw/cbasebal.o obj/drivers/cbasebal.o \
         obj/vidhrdw/cps1.o obj/drivers/cps1.o \

obj/capbowl.a: \
         obj/machine/capbowl.o obj/vidhrdw/capbowl.o obj/vidhrdw/tms34061.o obj/drivers/capbowl.o \

obj/gremlin.a: \
         obj/vidhrdw/blockade.o obj/drivers/blockade.o \

obj/vicdual.a: \
         obj/vidhrdw/vicdual.o obj/drivers/vicdual.o \
         obj/sndhrdw/carnival.o obj/sndhrdw/depthch.o obj/sndhrdw/invinco.o obj/sndhrdw/pulsar.o \

obj/sega.a: \
         obj/machine/segacrpt.o \
         obj/vidhrdw/sega.o obj/sndhrdw/sega.o obj/machine/sega.o obj/drivers/sega.o \
         obj/vidhrdw/segar.o obj/sndhrdw/segar.o obj/machine/segar.o obj/drivers/segar.o \
         obj/sndhrdw/monsterb.o \
         obj/vidhrdw/zaxxon.o obj/sndhrdw/zaxxon.o obj/drivers/zaxxon.o \
         obj/sndhrdw/congo.o obj/drivers/congo.o \
         obj/machine/turbo.o obj/vidhrdw/turbo.o obj/drivers/turbo.o \
         obj/drivers/kopunch.o \
         obj/vidhrdw/suprloco.o obj/drivers/suprloco.o \
         obj/vidhrdw/champbas.o obj/drivers/champbas.o \
         obj/vidhrdw/appoooh.o obj/drivers/appoooh.o \
         obj/vidhrdw/bankp.o obj/drivers/bankp.o \
 obj/vidhrdw/dotrikun.o obj/drivers/dotrikun.o \
         obj/vidhrdw/system1.o obj/drivers/system1.o \
         obj/machine/system16.o obj/vidhrdw/system16.o obj/sndhrdw/system16.o obj/drivers/system16.o \

obj/dataeast.a: \
         obj/machine/btime.o obj/vidhrdw/btime.o obj/drivers/btime.o \
         obj/vidhrdw/astrof.o obj/sndhrdw/astrof.o obj/drivers/astrof.o \
         obj/vidhrdw/kchamp.o obj/drivers/kchamp.o \
         obj/vidhrdw/firetrap.o obj/drivers/firetrap.o \
         obj/vidhrdw/brkthru.o obj/drivers/brkthru.o \
         obj/vidhrdw/shootout.o obj/drivers/shootout.o \
         obj/vidhrdw/sidepckt.o obj/drivers/sidepckt.o \
         obj/vidhrdw/exprraid.o obj/drivers/exprraid.o \
         obj/vidhrdw/pcktgal.o obj/drivers/pcktgal.o \
         obj/vidhrdw/actfancr.o obj/drivers/actfancr.o \
         obj/vidhrdw/dec8.o obj/drivers/dec8.o \
         obj/vidhrdw/karnov.o obj/drivers/karnov.o \
         obj/machine/dec0.o obj/vidhrdw/dec0.o obj/drivers/dec0.o \
         obj/vidhrdw/stadhero.o obj/drivers/stadhero.o \
         obj/vidhrdw/madmotor.o obj/drivers/madmotor.o \
         obj/vidhrdw/vaportra.o obj/drivers/vaportra.o \
         obj/vidhrdw/cbuster.o obj/drivers/cbuster.o \
         obj/vidhrdw/darkseal.o obj/drivers/darkseal.o \
         obj/vidhrdw/supbtime.o obj/drivers/supbtime.o \
         obj/vidhrdw/cninja.o obj/drivers/cninja.o \
         obj/vidhrdw/tumblep.o obj/drivers/tumblep.o \
         obj/vidhrdw/funkyjet.o obj/drivers/funkyjet.o \

obj/tehkan.a: \
         obj/sndhrdw/senjyo.o obj/vidhrdw/senjyo.o obj/drivers/senjyo.o \
         obj/vidhrdw/bombjack.o obj/drivers/bombjack.o \
         obj/vidhrdw/pbaction.o obj/drivers/pbaction.o \
         obj/vidhrdw/pontoon.o obj/drivers/pontoon.o \
         obj/vidhrdw/tehkanwc.o obj/drivers/tehkanwc.o \
         obj/vidhrdw/solomon.o obj/drivers/solomon.o \
         obj/vidhrdw/tecmo.o obj/drivers/tecmo.o \
         obj/vidhrdw/gaiden.o obj/drivers/gaiden.o \
         obj/vidhrdw/wc90.o obj/drivers/wc90.o \
         obj/vidhrdw/wc90b.o obj/drivers/wc90b.o \

obj/konami.a: \
         obj/sndhrdw/timeplt.o \
         obj/vidhrdw/tutankhm.o obj/drivers/tutankhm.o \
         obj/drivers/junofrst.o \
         obj/vidhrdw/pooyan.o obj/drivers/pooyan.o \
         obj/vidhrdw/timeplt.o obj/drivers/timeplt.o \
         obj/vidhrdw/megazone.o obj/drivers/megazone.o \
         obj/vidhrdw/pandoras.o obj/drivers/pandoras.o \
         obj/sndhrdw/gyruss.o obj/vidhrdw/gyruss.o obj/drivers/gyruss.o \
         obj/machine/konami.o obj/vidhrdw/trackfld.o obj/sndhrdw/trackfld.o obj/drivers/trackfld.o \
         obj/vidhrdw/rocnrope.o obj/drivers/rocnrope.o \
         obj/vidhrdw/circusc.o obj/drivers/circusc.o \
         obj/machine/tp84.o obj/vidhrdw/tp84.o obj/drivers/tp84.o \
         obj/vidhrdw/hyperspt.o obj/drivers/hyperspt.o \
         obj/vidhrdw/sbasketb.o obj/drivers/sbasketb.o \
         obj/vidhrdw/mikie.o obj/drivers/mikie.o \
         obj/vidhrdw/yiear.o obj/drivers/yiear.o \
         obj/vidhrdw/shaolins.o obj/drivers/shaolins.o \
         obj/vidhrdw/pingpong.o obj/drivers/pingpong.o \
         obj/vidhrdw/gberet.o obj/drivers/gberet.o \
         obj/vidhrdw/jailbrek.o obj/drivers/jailbrek.o \
         obj/vidhrdw/finalizr.o obj/drivers/finalizr.o \
         obj/vidhrdw/ironhors.o obj/drivers/ironhors.o \
         obj/machine/jackal.o obj/vidhrdw/jackal.o obj/drivers/jackal.o \
         obj/machine/ddrible.o obj/vidhrdw/ddrible.o obj/drivers/ddrible.o \
         obj/vidhrdw/contra.o obj/drivers/contra.o \
         obj/machine/combatsc.o obj/vidhrdw/combatsc.o obj/drivers/combatsc.o \
         obj/vidhrdw/hcastle.o obj/drivers/hcastle.o \
         obj/vidhrdw/nemesis.o obj/drivers/nemesis.o \
         obj/vidhrdw/konamiic.o \
         obj/vidhrdw/rockrage.o obj/drivers/rockrage.o \
         obj/vidhrdw/flkatck.o obj/drivers/flkatck.o \
 obj/vidhrdw/fastlane.o obj/drivers/fastlane.o \
         obj/vidhrdw/battlnts.o obj/drivers/battlnts.o \
         obj/vidhrdw/bladestl.o obj/drivers/bladestl.o \
         obj/machine/ajax.o obj/vidhrdw/ajax.o obj/drivers/ajax.o \
         obj/vidhrdw/thunderx.o obj/drivers/thunderx.o \
         obj/vidhrdw/mainevt.o obj/drivers/mainevt.o \
         obj/vidhrdw/88games.o obj/drivers/88games.o \
         obj/vidhrdw/gbusters.o obj/drivers/gbusters.o \
         obj/vidhrdw/crimfght.o obj/drivers/crimfght.o \
         obj/vidhrdw/spy.o obj/drivers/spy.o \
         obj/vidhrdw/bottom9.o obj/drivers/bottom9.o \
         obj/vidhrdw/blockhl.o obj/drivers/blockhl.o \
         obj/vidhrdw/aliens.o obj/drivers/aliens.o \
         obj/vidhrdw/surpratk.o obj/drivers/surpratk.o \
         obj/vidhrdw/parodius.o obj/drivers/parodius.o \
         obj/vidhrdw/rollerg.o obj/drivers/rollerg.o \
         obj/vidhrdw/xexex.o obj/drivers/xexex.o \
         obj/machine/simpsons.o obj/vidhrdw/simpsons.o obj/drivers/simpsons.o \
         obj/vidhrdw/vendetta.o obj/drivers/vendetta.o \
         obj/vidhrdw/twin16.o obj/drivers/twin16.o \
 obj/vidhrdw/gradius3.o obj/drivers/gradius3.o \
         obj/vidhrdw/tmnt.o obj/drivers/tmnt.o \
         obj/vidhrdw/xmen.o obj/drivers/xmen.o \
         obj/vidhrdw/wecleman.o obj/drivers/wecleman.o \

obj/exidy.a: \
         obj/machine/exidy.o obj/vidhrdw/exidy.o obj/sndhrdw/exidy.o obj/drivers/exidy.o \
         obj/sndhrdw/targ.o \
         obj/vidhrdw/circus.o obj/drivers/circus.o \
         obj/machine/starfire.o obj/vidhrdw/starfire.o obj/drivers/starfire.o \
         obj/sndhrdw/exidy440.o obj/vidhrdw/exidy440.o obj/drivers/exidy440.o \

obj/atari.a: \
         obj/machine/atari_vg.o \
         obj/machine/asteroid.o obj/sndhrdw/asteroid.o \
 obj/vidhrdw/llander.o obj/drivers/asteroid.o \
         obj/drivers/bwidow.o \
         obj/sndhrdw/bzone.o  obj/drivers/bzone.o \
         obj/sndhrdw/redbaron.o \
         obj/drivers/tempest.o \
         obj/machine/starwars.o obj/machine/swmathbx.o \
         obj/drivers/starwars.o obj/sndhrdw/starwars.o \
         obj/machine/mhavoc.o obj/drivers/mhavoc.o \
         obj/machine/quantum.o obj/drivers/quantum.o \
         obj/machine/atarifb.o obj/vidhrdw/atarifb.o obj/drivers/atarifb.o \
         obj/machine/sprint2.o obj/vidhrdw/sprint2.o obj/drivers/sprint2.o \
         obj/machine/sbrkout.o obj/vidhrdw/sbrkout.o obj/drivers/sbrkout.o \
         obj/machine/dominos.o obj/vidhrdw/dominos.o obj/drivers/dominos.o \
         obj/vidhrdw/nitedrvr.o obj/machine/nitedrvr.o obj/drivers/nitedrvr.o \
         obj/vidhrdw/bsktball.o obj/machine/bsktball.o obj/drivers/bsktball.o \
         obj/vidhrdw/copsnrob.o obj/machine/copsnrob.o obj/drivers/copsnrob.o \
         obj/machine/avalnche.o obj/vidhrdw/avalnche.o obj/drivers/avalnche.o \
         obj/machine/subs.o obj/vidhrdw/subs.o obj/drivers/subs.o \
         obj/machine/atarifb.o obj/vidhrdw/atarifb.o obj/drivers/atarifb.o \
         obj/vidhrdw/canyon.o obj/drivers/canyon.o \
         obj/vidhrdw/skydiver.o obj/drivers/skydiver.o \
         obj/vidhrdw/warlord.o obj/drivers/warlord.o \
         obj/machine/centiped.o obj/vidhrdw/centiped.o obj/drivers/centiped.o \
         obj/machine/milliped.o obj/vidhrdw/milliped.o obj/drivers/milliped.o \
         obj/vidhrdw/qwakprot.o obj/drivers/qwakprot.o \
         obj/machine/kangaroo.o obj/vidhrdw/kangaroo.o obj/drivers/kangaroo.o \
         obj/machine/arabian.o obj/vidhrdw/arabian.o obj/drivers/arabian.o \
         obj/machine/missile.o obj/vidhrdw/missile.o obj/drivers/missile.o \
         obj/machine/foodf.o obj/vidhrdw/foodf.o obj/drivers/foodf.o \
         obj/vidhrdw/liberatr.o obj/machine/liberatr.o obj/drivers/liberatr.o \
         obj/vidhrdw/ccastles.o obj/drivers/ccastles.o \
         obj/machine/cloak.o obj/vidhrdw/cloak.o obj/drivers/cloak.o \
         obj/vidhrdw/cloud9.o obj/drivers/cloud9.o \
         obj/machine/jedi.o obj/vidhrdw/jedi.o obj/sndhrdw/jedi.o obj/drivers/jedi.o \
         obj/machine/atarigen.o obj/sndhrdw/atarijsa.o \
         obj/machine/slapstic.o \
         obj/vidhrdw/atarisy1.o obj/drivers/atarisy1.o \
         obj/vidhrdw/atarisy2.o obj/drivers/atarisy2.o \
         obj/vidhrdw/gauntlet.o obj/drivers/gauntlet.o \
         obj/vidhrdw/atetris.o obj/drivers/atetris.o \
         obj/vidhrdw/toobin.o obj/drivers/toobin.o \
         obj/vidhrdw/vindictr.o obj/drivers/vindictr.o \
         obj/vidhrdw/klax.o obj/drivers/klax.o \
         obj/vidhrdw/blstroid.o obj/drivers/blstroid.o \
         obj/vidhrdw/xybots.o obj/drivers/xybots.o \
         obj/vidhrdw/eprom.o obj/drivers/eprom.o \
         obj/vidhrdw/skullxbo.o obj/drivers/skullxbo.o \
         obj/vidhrdw/badlands.o obj/drivers/badlands.o \
         obj/vidhrdw/cyberbal.o obj/drivers/cyberbal.o \
         obj/vidhrdw/rampart.o obj/drivers/rampart.o \
         obj/vidhrdw/shuuz.o obj/drivers/shuuz.o \
         obj/vidhrdw/hydra.o obj/drivers/hydra.o \
         obj/vidhrdw/thunderj.o obj/drivers/thunderj.o \
         obj/vidhrdw/batman.o obj/drivers/batman.o \
         obj/vidhrdw/relief.o obj/drivers/relief.o \
         obj/vidhrdw/offtwall.o obj/drivers/offtwall.o \
         obj/vidhrdw/arcadecl.o obj/drivers/arcadecl.o \

obj/rockola.a: \
         obj/vidhrdw/rockola.o obj/sndhrdw/rockola.o obj/drivers/rockola.o \
         obj/vidhrdw/warpwarp.o obj/drivers/warpwarp.o \

obj/snk.a: \
         obj/drivers/munchmo.o \
         obj/vidhrdw/marvins.o obj/drivers/marvins.o \
 obj/drivers/hal21.o \
         obj/vidhrdw/snk.o obj/drivers/snk.o \
         obj/vidhrdw/snk68.o obj/drivers/snk68.o \
         obj/vidhrdw/prehisle.o obj/drivers/prehisle.o \
         obj/vidhrdw/alpha68k.o obj/drivers/alpha68k.o \

obj/technos.a: \
         obj/drivers/scregg.o \
         obj/vidhrdw/tagteam.o obj/drivers/tagteam.o \
         obj/vidhrdw/ssozumo.o obj/drivers/ssozumo.o \
         obj/vidhrdw/mystston.o obj/drivers/mystston.o \
         obj/vidhrdw/bogeyman.o obj/drivers/bogeyman.o \
         obj/vidhrdw/matmania.o obj/drivers/matmania.o obj/machine/maniach.o \
         obj/vidhrdw/renegade.o obj/drivers/renegade.o \
         obj/vidhrdw/xain.o obj/drivers/xain.o \
         obj/vidhrdw/battlane.o obj/drivers/battlane.o \
         obj/vidhrdw/ddragon.o obj/drivers/ddragon.o \
         obj/vidhrdw/ddragon3.o obj/drivers/ddragon3.o \
         obj/vidhrdw/blockout.o obj/drivers/blockout.o \

obj/berzerk.a: \
         obj/machine/berzerk.o obj/vidhrdw/berzerk.o obj/sndhrdw/berzerk.o obj/drivers/berzerk.o \

obj/gameplan.a: \
         obj/vidhrdw/gameplan.o obj/drivers/gameplan.o \

obj/stratvox.a: \
         obj/vidhrdw/route16.o obj/drivers/route16.o \

obj/zaccaria.a: \
         obj/vidhrdw/zaccaria.o obj/drivers/zaccaria.o \

obj/upl.a: \
         obj/vidhrdw/nova2001.o obj/drivers/nova2001.o \
         obj/vidhrdw/pkunwar.o obj/drivers/pkunwar.o \
         obj/vidhrdw/ninjakd2.o obj/drivers/ninjakd2.o \
         obj/vidhrdw/mnight.o obj/drivers/mnight.o \

obj/tms.a: \
         obj/machine/exterm.o obj/vidhrdw/exterm.o obj/drivers/exterm.o \
         obj/machine/smashtv.o obj/vidhrdw/smashtv.o obj/drivers/smashtv.o \

obj/cinemar.a: \
         obj/vidhrdw/jack.o obj/drivers/jack.o \

obj/cinemav.a: \
         obj/sndhrdw/cinemat.o obj/drivers/cinemat.o \
         obj/machine/cchasm.o obj/vidhrdw/cchasm.o obj/sndhrdw/cchasm.o obj/drivers/cchasm.o \

obj/thepit.a: \
         obj/vidhrdw/thepit.o obj/drivers/thepit.o \

obj/valadon.a: \
         obj/machine/bagman.o obj/vidhrdw/bagman.o obj/drivers/bagman.o \

obj/seibu.a: \
         obj/vidhrdw/wiz.o obj/drivers/wiz.o \
         obj/machine/stfight.o obj/vidhrdw/stfight.o obj/drivers/stfight.o \
 obj/sndhrdw/seibu.o \
         obj/vidhrdw/dynduke.o obj/drivers/dynduke.o \
         obj/vidhrdw/raiden.o obj/drivers/raiden.o \
         obj/vidhrdw/dcon.o obj/drivers/dcon.o \

obj/tad.a: \
 obj/vidhrdw/cabal.o obj/drivers/cabal.o \
 obj/vidhrdw/toki.o obj/drivers/toki.o \
 obj/vidhrdw/bloodbro.o obj/drivers/bloodbro.o \

obj/jaleco.a: \
         obj/vidhrdw/exerion.o obj/drivers/exerion.o \
         obj/vidhrdw/aeroboto.o obj/drivers/aeroboto.o \
         obj/vidhrdw/citycon.o obj/drivers/citycon.o \
         obj/vidhrdw/psychic5.o obj/drivers/psychic5.o \
         obj/vidhrdw/ginganin.o obj/drivers/ginganin.o \
         obj/vidhrdw/megasys1.o obj/drivers/megasys1.o \
 obj/vidhrdw/cischeat.o obj/drivers/cischeat.o \

obj/visco.a: \
         obj/vidhrdw/aerofgt.o obj/drivers/aerofgt.o \

obj/leland.a: \
         obj/machine/8254pit.o obj/vidhrdw/leland.o obj/drivers/leland.o \
         obj/drivers/ataxx.o \

obj/orca.a: \
         obj/vidhrdw/marineb.o obj/drivers/marineb.o \
         obj/vidhrdw/funkybee.o obj/drivers/funkybee.o \
         obj/vidhrdw/zodiack.o obj/drivers/zodiack.o \
         obj/machine/espial.o obj/vidhrdw/espial.o obj/drivers/espial.o \
         obj/machine/vastar.o obj/vidhrdw/vastar.o obj/drivers/vastar.o \

obj/gaelco.a: \
         obj/vidhrdw/gaelco.o obj/drivers/gaelco.o \

# obj/neogeo.a: \
#          obj/machine/neogeo.o obj/machine/pd4990a.o obj/vidhrdw/neogeo.o obj/drivers/neogeo.o \

obj/other.a: \
         obj/vidhrdw/pong.o obj/sndhrdw/pong.o obj/drivers/pong.o \
         obj/vidhrdw/spacefb.o obj/sndhrdw/spacefb.o obj/drivers/spacefb.o \
         obj/vidhrdw/blueprnt.o obj/drivers/blueprnt.o \
         obj/drivers/omegrace.o \
         obj/vidhrdw/tankbatt.o obj/drivers/tankbatt.o \
         obj/vidhrdw/dday.o obj/sndhrdw/dday.o obj/drivers/dday.o \
         obj/vidhrdw/gundealr.o obj/drivers/gundealr.o \
         obj/machine/leprechn.o obj/vidhrdw/leprechn.o obj/drivers/leprechn.o \
         obj/vidhrdw/hexa.o obj/drivers/hexa.o \
         obj/vidhrdw/redalert.o obj/sndhrdw/redalert.o obj/drivers/redalert.o \
         obj/machine/irobot.o obj/vidhrdw/irobot.o obj/drivers/irobot.o \
         obj/machine/spiders.o obj/vidhrdw/crtc6845.o obj/vidhrdw/spiders.o obj/drivers/spiders.o \
         obj/machine/stactics.o obj/vidhrdw/stactics.o obj/drivers/stactics.o \
         obj/vidhrdw/sharkatt.o obj/drivers/sharkatt.o \
         obj/vidhrdw/kingobox.o obj/drivers/kingobox.o \
         obj/vidhrdw/zerozone.o obj/drivers/zerozone.o \
         obj/machine/exctsccr.o obj/vidhrdw/exctsccr.o obj/drivers/exctsccr.o \
         obj/vidhrdw/speedbal.o obj/drivers/speedbal.o \
         obj/vidhrdw/sauro.o obj/drivers/sauro.o \
         obj/vidhrdw/galpanic.o obj/drivers/galpanic.o \
         obj/vidhrdw/airbustr.o obj/drivers/airbustr.o \
         obj/vidhrdw/ambush.o obj/drivers/ambush.o \
         obj/vidhrdw/starcrus.o obj/drivers/starcrus.o \
         obj/drivers/shanghai.o \
         obj/vidhrdw/goindol.o obj/drivers/goindol.o \
         obj/drivers/dlair.o \
         obj/vidhrdw/goldstar.o obj/drivers/goldstar.o \
         obj/vidhrdw/csk.o obj/drivers/csk.o \
         obj/vidhrdw/meteor.o obj/drivers/meteor.o \
         obj/vidhrdw/bjtwin.o obj/drivers/bjtwin.o \
         obj/vidhrdw/aztarac.o obj/sndhrdw/aztarac.o obj/drivers/aztarac.o \
 obj/vidhrdw/pinbo.o obj/drivers/pinbo.o

!endif    # endif of !ifdef MAME

# neogeo should properly span the domains of mame and mess (MVS & ?...)

obj/neogeo.a: \
         obj/machine/neogeo.o obj/machine/pd4990a.o obj/vidhrdw/neogeo.o obj/drivers/neogeo.o \

NEO_CORE=obj/machine/neogeo.o obj/machine/pd4990a.o obj/vidhrdw/neogeo.o obj/drivers/neogeo.o


# dependencies

!ifndef WIN32_

obj/cpu/z80/z80.o: z80.c z80.h z80daa.h



obj/cpu/i8085/i8085.o: i8085.c i8085.h i8085cpu.h i8085daa.h
obj/cpu/m6502/m6502.o: m6502.c m6502.h m6502ops.h tbl6502.c tbl65c02.c tbl6510.c
obj/cpu/m6502/h6280.o: h6280.c h6280.h h6280ops.h tblh6280.c
obj/cpu/i86/i86.o:  i86.c i86.h i86intrf.h ea.h host.h instr.h modrm.h
obj/cpu/m6800/m6800.o:m6800.c m6800.h 6800ops.c
obj/cpu/m6805/m6805.o:m6805.c m6805.h 6805ops.c
obj/cpu/m6809/m6809.o:m6809.c m6809.h 6809ops.c 6809tbl.c
obj/cpu/tms34010/tms34010.o: tms34010.c tms34010.h 34010ops.c 34010tbl.c
obj/cpu/tms9900/tms9900.o: tms9900.c tms9900.h 9900stat.h
obj/cpu/z8000/z8000.o: z8000.c z8000.h z8000cpu.h z8000dab.h z8000ops.c z8000tbl.c
obj/cpu/tms32010/tms32010.o: tms32010.c tms32010.h
obj/cpu/ccpu/ccpu.o: ccpu.h ccpudasm.c
obj/cpu/m68000/m68kcpu.o: obj/cpu/m68000/m68kops.c m68kmake.c m68k_in.c

!endif




# NOTE: hard tab indentations will cause the win32 makefile preprocessor
# to choke...

!ifndef WIN32_

$(EMULATOR_EXE):  $(COREOBJS) $(MSDOSOBJS) $(OBJS) $(LIBS)
    $(CC) $(CDEFS) $(CFLAGS) $(TINYFLAGS) -c src/version.c -o obj/version.o
    $(LD) $(LDFLAGS) $(COREOBJS) $(MSDOSOBJS) $(OBJS) $(LIBS) -o $@
!ifdef EXECOMPRESS
    $(EXECOMPESS) $(EMULATOR_EXE)
!endif

romcmp.exe: obj/romcmp.o obj/unzip.o
    $(LD) $(LDFLAGS) $^ -lz -o $@

!endif


win32:
    perl testcv.pl < makefile > nmake.mak
    nmake -f nmake.mak WIN32_=1

win32clean:
    perl testcv.pl < makefile > nmake.mak
    nmake -f nmake.mak clean
    nmake -f nmake.mak maketree WIN32_=1
    nmake -f nmake.mak WIN32_=1





!ifdef WIN32_

# CPU_DIRS = obj/cpu/ccpu/*.o obj/cpu/gensync/*.o obj/cpu/h6280/*.o obj/cpu/i8039/*.o obj/cpu/i8085/*.o obj/cpu/i86/*.o obj/cpu/konami/*.o obj/cpu/m6502/*.o obj/cpu/m6800/*.o obj/cpu/m68000/*.o obj/cpu/m6805/*.o obj/cpu/m6809/*.o obj/cpu/nec/*.o obj/cpu/pdp1/*.o obj/cpu/s2650/*.o obj/cpu/t11/*.o obj/cpu/tms32010/*.o obj/cpu/tms34010/*.o obj/cpu/tms9900/*.o obj/cpu/z80/*.o obj/cpu/z8000/*.o
!ifndef DEBUG
CPU_DIRS=$(CPUOBJS)
!else
CPU_DIRS=$(CPUOBJS) $(DBGOBJS)
!endif

!ifdef MAME_NET
WIN32_OBJS=$(WIN32_OBJS) $(NET_OBJS)
!endif


# MAME_DIRS = obj/*.o obj/systems/*.o obj/sound/*.o obj/sndhrdw/*.o obj/vidhrdw/*.o obj/drivers/*.o obj/machine/*.o 
!ifdef MAME
MAME_DIRS = obj/*.o obj/systems/*.o obj/sound/*.o obj/sndhrdw/*.o obj/vidhrdw/*.o obj/drivers/*.o obj/machine/*.o
!endif

# MESS_DIRS = obj/*.o obj/sound/*.o obj/sndhrdw/*.o obj/vidhrdw/*.o obj/mess/*.o obj/mess/vidhrdw/*.o obj/mess/sndhrdw/*.o obj/mess/machine/*.o obj/mess/systems/*.o  obj/machine/6821pia.o
# MESS_DIRS = obj/*.o obj/sound/*.o obj/mess/*.o obj/mess/vidhrdw/*.o obj/mess/sndhrdw/*.o obj/mess/machine/*.o obj/mess/systems/*.o  obj/machine/6821pia.o
!ifdef MESS
MESS_DIRS = obj/mess/vidhrdw/*.o obj/mess/sndhrdw/*.o obj/mess/machine/*.o obj/mess/systems/*.o  obj/machine/6821pia.o
!endif

!ifdef NEOGEO
NEO_DIRS=$(NEO_CORE)
!endif

# mame32.exe: $(COREOBJS) $(CPU_DIRS) $(WIN32_OBJS) $(OBJS) $(RES)
$(EMULATOR_EXE): $(COREOBJS) $(CPU_DIRS) $(WIN32_OBJS) $(OBJS) $(RES)
    $(LD) $(LDFLAGS) -out:$(EMULATOR_EXE) $(COREOBJS) $(MESS_DIRS) $(MAME_DIRS) $(NEO_DIRS) $(CPU_DIRS) $(WIN32_OBJS) $(RES) $(LIBS) $(NET_LIBS)

!endif

makedir:
    @echo make makedir is no longer necessary, just type make

maketree:
    md obj
    md obj\cpu
    md obj\cpu\gensync
    md obj\cpu\z80
    md obj\cpu\z80gb
    md obj\cpu\m6502
    md obj\cpu\h6280
    md obj\cpu\i86
    md obj\cpu\nec
    md obj\cpu\i8039
    md obj\cpu\i8085
    md obj\cpu\m6800
    md obj\cpu\m6805
    md obj\cpu\m6809
    md obj\cpu\konami
    md obj\cpu\m68000
    md obj\cpu\s2650
    md obj\cpu\t11
    md obj\cpu\tms34010
    md obj\cpu\tms9900
    md obj\cpu\z8000
    md obj\cpu\tms32010
    md obj\cpu\adsp2100
    md obj\cpu\ccpu
    md obj\cpu\pdp1
    md obj\sound
    md obj\drivers
    md obj\machine
    md obj\vidhrdw
    md obj\sndhrdw
    md obj\msdos
!ifdef MESS
    md obj\mess
    md obj\mess\machine
    md obj\mess\systems
    md obj\mess\vidhrdw
    md obj\mess\sndhrdw
!endif
!ifdef WIN32
    md obj\Win32
!endif

clean:
    deltree /Y obj
    $(RM) $(EMULATOR_EXE)
    $(RM) romcmp.exe
    
cleandebug:
    $(RM) obj\*.o
    $(RM) obj\cpu\gensync\*.o
    $(RM) obj\cpu\z80\*.o
    $(RM) obj\cpu\z80\*.oa
    $(RM) obj\cpu\z80\*.asm
    $(RM) obj\cpu\z80\*.exe
    $(RM) obj\cpu\m6502\*.o
    $(RM) obj\cpu\h6280\*.o
    $(RM) obj\cpu\i86\*.o
    $(RM) obj\cpu\nec\*.o
    $(RM) obj\cpu\i8039\*.o
    $(RM) obj\cpu\i8085\*.o
    $(RM) obj\cpu\m6800\*.o
    $(RM) obj\cpu\m6800\*.oa
    $(RM) obj\cpu\m6800\*.exe
    $(RM) obj\cpu\m6805\*.o
    $(RM) obj\cpu\m6809\*.o
    $(RM) obj\cpu\konami\*.o
    $(RM) obj\cpu\m68000\*.o
    $(RM) obj\cpu\m68000\*.c
    $(RM) obj\cpu\m68000\*.h
    $(RM) obj\cpu\m68000\*.oa
    $(RM) obj\cpu\m68000\*.og
    $(RM) obj\cpu\m68000\*.asm
    $(RM) obj\cpu\m68000\*.exe
    $(RM) obj\cpu\s2650\*.o
    $(RM) obj\cpu\t11\*.o
    $(RM) obj\cpu\tms34010\*.o
    $(RM) obj\cpu\tms9900\*.o
    $(RM) obj\cpu\z8000\*.o
    $(RM) obj\cpu\tms32010\*.o
    $(RM) obj\cpu\adsp2100\*.o
    $(RM) obj\cpu\ccpu\*.o
    $(RM) obj\cpu\pdp1\*.o
    $(RM) $(EMULATOR_EXE)

cleantiny:
    $(RM) obj/mame.o
    $(RM) obj/driver.o
    $(RM) obj/usrintrf.o
    $(RM) obj/cheat.o
    $(RM) obj/cpuintrf.o
    $(RM) obj/sndintrf.o
    $(RM) obj/sound/fm.o
    $(RM) obj/msdos/fronthlp.o
    $(RM) obj/msdos/msdos.o
    $(RM) obj/msdos/fileio.o
    $(RM) obj/msdos/config.o
    $(RM) obj/vidhrdw/konamiic.o
    $(RM) obj/mess/system.o
    $(RM) $(EMULATOR_EXE)
!ifdef NEOGEO
    $(RM) $(NEO_CORE)
!endif

cleancore:
    $(RM) $(COREOBJS)

# cleantiny:
#     $(RM) obj\mame.o
#     $(RM) obj\driver.o
#     $(RM) obj\usrintrf.o
#     $(RM) obj\cheat.o
#     $(RM) obj\cpuintrf.o
#     $(RM) obj\sndintrf.o
#     $(RM) obj\sound\fm.o
#     $(RM) obj\msdos\fronthlp.o
#     $(RM) obj\vidhrdw\konamiic.o
#     $(RM) obj\mess\system.o


# if you switch the state of MESS on or off, you have to rebuild
# all mess components...  Looking into altering this...
cleanmess:
    $(RM) obj/mess/machine/6821pia.o
    $(RM) obj/mess/sndhrdw/*.o
    $(RM) obj/mess/systems/*.o
    $(RM) obj/mess/vidhrdw/*.o
    $(RM) obj/mess/*.o
    $(RM) obj/*.a
    $(RM) obj/*.o
    $(RM) obj/sound/*.o
    $(RM) obj/sndhrdw/*.o
    $(RM) obj/vidhrdw/*.o

cleanmedium:
    $(RM) obj/sound/2610intf.o \
    $(RM) obj/mame.o \
    $(RM) obj/driver.o \
    $(RM) obj/usrintrf.o \
    $(RM) obj/cheat.o \
    $(RM) obj/msdos/fronthlp.o \
    $(RM) obj/sound/fm.o \
    $(RM) obj/sound/votrax.o \
    $(RM) obj/mess/system.o \
    $(RM) obj/mess/mess.o \
    $(RM) obj/info.o \
    $(RM) obj/cpuintrf.o \
    $(RM) obj/sndintrf.o \
    $(RM) obj/msdos/msdos.o 

cleancpu:
    $(RM) obj\cpu\*\*

mess32dist:
    zip ../ms323614.zip mess32.exe *.txt

mess32srcdist:
    makedist.bat
