/******************************************************************************

  driver.c/system.c for MESS

  The list of all available drivers. Drivers have to be included here to be
  recognized by the executable.

  To save some typing, we use a hack here. This file is recursively #included
  twice, with different definitions of the DRIVER() macro. The first one
  declares external references to the drivers; the second one builds an array
  storing all the drivers.

******************************************************************************/

#include "driver.h"

#ifdef TINY_COMPILE

extern struct GameDriver TINY_NAME;

const struct GameDriver *drivers[] =
{
	(struct GameDriver *)&TINY_NAME,
	0
	/* end of array */
};

#else

#ifndef DRIVER_RECURSIVE

#ifdef MME
/* The "root" driver, defined so we can have &driver_##NAME in macros. */
struct GameDriver driver_ =
{
	__FILE__,
	0,
	"root",
	0,
	0,
	0,
	0,
	0,
	0,
	0,

	0,
	0, 0,
	0,
	0,
	0,
	0, 0, 0,
	NOT_A_DRIVER,
	0,0
};


// need two dummy functions cause win32 compile can't handle
// macro's lacking arguments (GAME & GAMEX)

//
//#ifdef WIN32
//

struct GameDriver driver_dummy =
{
	__FILE__,
	0,
	"dummy",
	0,
	0,
	0,
	0,
	0,
	0,
	0,

	0,
	0, 0,
	0,
	0,
	0,
	0, 0, 0,
	NOT_A_DRIVER,
	0,0
};

void init_dummy(void)
{}

// #endif

#endif


#define DRIVER_RECURSIVE

/* step 1: declare all external references */
#define DRIVER(NAME) extern struct GameDriver (driver_##NAME);
#define TESTDRIVER(NAME) extern struct GameDriver (driver_##NAME);
#define DRIVERMESS(NAME) extern struct GameDriver (NAME##_driver);
#define TESTDRIVERMESS(NAME) extern struct GameDriver (NAME##_driver);



#if (MAME || NEOGEO)

#undef NEOFREE
#undef NEOMAME
#ifndef NEOGEO
#define NEOFREE 1
#endif
#ifndef MAME
#define NEOMAME 1
#endif

#include "../driver.c"
#endif


#include "system.c"

/* step 2: define the drivers[] array */
#undef DRIVER
#undef TESTDRIVER
#undef DRIVERMESS
#undef TESTDRIVERMESS

#define DRIVER(NAME) &(driver_##NAME),
#define TESTDRIVER(NAME)
#define DRIVERMESS(NAME) &(NAME##_driver),
/*
#define DRIVERMESS(NAME) &(##NAME_driver),
*/
#define TESTDRIVERMESS(NAME)
const struct GameDriver *drivers[] =
{

/* if either of MAME or NEOGEO is definted, need to include the driver */

#ifdef MAME
#include "../driver.c"
#else
#ifdef NEOGEO
#include "../driver.c"
#endif
#endif
#include "system.c"
	0	/* end of array */
};

#else	/* DRIVER_RECURSIVE */

#ifdef MESS



  /****************THESE DRIVERS WORK OK***************************************/

      DRIVERMESS( a800 )        /* Atari 800                                      */

      DRIVERMESS( a5200 )       /* Atari 5200                                     */
      DRIVERMESS( a7800 )       /* Atari 7800                                     */

      DRIVERMESS( amiga )       /* Commodore Amiga                                */

      DRIVERMESS( apple2c )     /* APPLE                                          */
      DRIVERMESS( apple2c0 )    /* APPLE                                          */
      DRIVERMESS( apple2cp )    /* APPLE                                          */
      DRIVERMESS( apple2e )     /* APPLE                                          */
      DRIVERMESS( apple2ee )    /* APPLE                                          */
      DRIVERMESS( apple2ep )    /* plus? - 1979                                   */


      DRIVERMESS( astrocde )    /* Bally Astrocade                                */

	TESTDRIVER( aszmic )	/* Timex/Sinclair */

      DRIVERMESS( cgenie )      /* Color Genie                                    */
      DRIVERMESS( coco )        /* Color Computer                                 */
	DRIVERMESS( coco3 )	/* Color Computer 3 */
      DRIVERMESS( coleco )      /* ColecoVision (Original BIOS )                  */

/* Please do not include these 2 in a distribution - Hacks */
//    DRIVERMESS( colecofb )    /* ColecoVision (Fast BIOS load)                  */
//    DRIVERMESS( coleconb )    /* ColecoVision (No BIOS load)                    */

	DRIVERMESS( c16 )	/* Commodore 16 */

	TESTDRIVERMESS( c64 )	/* Commodore 64 */
	TESTDRIVERMESS( c128 )	/* Commodore 128 */

	DRIVERMESS( cp400 )		/* Prologica CP400 */
  TESTDRIVERMESS( cpc464 )      /* Amstrad (Schneider in Germany) 1984            */
  TESTDRIVERMESS( cpc664 )      /* Amstrad (Schneider in Germany) 1985            */
      DRIVERMESS( cpc6128 )     /* Amstrad (Schneider in Germany) 1985                                    */
  TESTDRIVERMESS( cpc464p )     /* Amstrad CPC464  Plus - 1987                    */
  TESTDRIVERMESS( cpc6128p )    /* Amstrad CPC6128 Plus - 1987                    */

      DRIVERMESS( dragon32 )    /* Dragon32                                       */

      DRIVERMESS( ep128 )       /* Enterprise 128 k                               */
	  DRIVERMESS( gameboy )		/* Nintendo Gameboy Handheld */
      DRIVERMESS( gamegear )    /* Sega Game Gear Handheld                        */
      DRIVERMESS( genesis )     /* Sega Genesis/MegaDrive                         */

	  DRIVERMESS( jupiter )		/* CANTAB */

      TESTDRIVERMESS( kaypro )      /* APPLE KAYPRO                                   */


      DRIVERMESS( kccomp )      /* KC compact                                     */

      DRIVERMESS( kim1 )        /* Commodore (MOS) KIM-1 1975                     */

	  DRIVERMESS( msx )			/* MSX */

      DRIVERMESS( nes )         /* Nintendo Entertainment System                  */
	DRIVERMESS( oric1 )
	DRIVERMESS( orica )

  TESTDRIVERMESS( pc )          /* IBM PC  - parent Driver, so no need            */
      DRIVERMESS( pcmda )
      DRIVERMESS( pccga )

      DRIVERMESS( pce )         /* PC/Engine - Turbo Graphics-16  NEC 1989-1993   */

      DRIVERMESS( pdp1 ) 	    /* DEC PDP1 for SPACEWAR! - 1962                  */
	DRIVERMESS( plus4 )	/* Commodore +4 */

      DRIVERMESS( raaspec )     /* RA+A Spectrum - Modified Vectrex               */

      DRIVERMESS( sms )         /* Sega Sega Master System                        */
	TESTDRIVERMESS( snes )		/* Super Nintendo */

      DRIVERMESS( spectrum )    /* Sinclair 48k                                   */

      DRIVERMESS( tandy1t )     /* Tandy                                          */

      TESTDRIVERMESS( ti99_2_24 )        /* Texas Instruments TI/994a                      */
      TESTDRIVERMESS( ti99_2_32 )        /* Texas Instruments TI/994a                      */
      TESTDRIVERMESS( ti99_4 )        /* Texas Instruments TI/994a                      */
      DRIVERMESS( ti99_4a )        /* Texas Instruments TI/994a                      */
	TESTDRIVER( ts1000 )	/* Timex/Sinclair */

      DRIVERMESS( trs80 )       /* TRS-80 Model I   - Radio Shack/Tandy           */

	  TESTDRIVERMESS( vboy )	/* Virtual Boy */
      DRIVERMESS( vectrex )     /* General Consumer Electric Vectrex - 1982-1984  */
                            /* aka Milton-Bradley Vectrex)                    */

	DRIVERMESS( vic20 )	/* Commodore Vic 20 */
	DRIVERMESS( vc20 )	/* Commodore VIC 20 PAL */
	DRIVERMESS( vz200 )	/* Video Tech 200 */
	DRIVERMESS( vz300 )	/* Video Tech 300 */

	TESTDRIVER( zx80 )	/* Timex/Sinclair */
	TESTDRIVER( zx81 )	/* Timex/Sinclair */







  /***********THESE DRIVERS EXISTS, BUT HAVE PROBLEMS OF SOME SORT*************/


//  DRIVERMESS( a2600 )       /* Atari 2600                                     */
//  DRIVERMESS( trs80m3 )     /* TRS-80 Model III - Radio Shack/Tandy           */
  DRIVERMESS( a800xl )      /* Atari 800 XL                                   */
//  DRIVERMESS( a130xe )      /* Atari 130 XE                                   */








  /****THESE DRIVERS DONT EXIST, BUT SHOULD ;-) *******************************/

    //DRIVERMESS( apple )       /* Apple - 1976                                   */
    //DRIVERMESS( applemac )    /* Apple Macintosh                                */
    //DRIVERMESS( arcadia )     /* Arcadia 2001                                   */
    //DRIVERMESS( atarist )     /* Atari ST                                       */

    //DRIVERMESS( bbcmicro )    /* BBC Micro                                      */

    //DRIVERMESS( c64 )         /* Commodore 64                                   */
    //DRIVERMESS( c128 )        /* Commodore 128                                  */
    //DRIVERMESS( channelf )    /* Fairchild Channel F VES - 1976                 */
    //DRIVERMESS( coco2 )       /* Color Computer 2                               */

    //DRIVERMESS( gameboy )     /* Nintendo GameBoy Handheld                      */

  							/* AkA Phillips Videopac                          */
    //DRIVERMESS( intv )        /* Mattel Intellivision - 1979 AKA INTV           */
    //DRIVERMESS( jaguar )      /* Atari Jaguar                                   */

    //DRIVERMESS( lynx )        /* Atari Lynx Handheld                            */
    //DRIVERMESS( msx )         /* MSX                                            */

    //DRIVERMESS( odyssey )     /* Magnavox Odyssey - analogue (1972)             */
    //DRIVERMESS( odyssey2 )    /* Magnavox Odyssey - 1978-1983                  */

    //DRIVERMESS( snes )        /* Nintendo Super Nintendo                        */

    //DRIVERMESS( trs80_m2 )    /* TRS-80 Model II -                              */


    //DRIVERMESS( vboy )        /* Nintendo Virtual Boy                           */
    //DRIVERMESS( vic20 )       /* Commodore Vic-20                               */

    //DRIVERMESS( x68000 )      /* X68000                                         */




#endif	/* MESS */

#endif	/* DRIVER_RECURSIVE */

#endif	/* TINY_COMPILE */
